@@ -11,8 +11,9 @@ fn main() {
         margin_r: 0,
         margin_b: 0,
         margin_l: 0,
-        flags: NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_PRESERVE_CURSOR | NCOPTION_SUPPRESS_BANNERS,
+        flags: NCOPTION_CLI_MODE,
     };
+
     unsafe {
         let nc = notcurses_init(&options, null_mut());
         if nc.is_null() {
