@@ -6,9 +6,10 @@ use libc::strcmp;
 
 use crate::{
     c_api::{
-        self, nccell_release, NcChannel_u32, NcChannels_u64, NcResult_i32, NcRgb_u32, NcStyle_u16,
+        self, nccell_release, NcAlpha_u32, NcChannel_u32, NcChannels_u64, NcResult_i32, NcRgb_u32,
+        NcStyle_u16,
     },
-    cstring, rstring, NcAlpha, NcCell, NcPaletteIndex, NcPlane,
+    cstring, rstring, NcCell, NcPaletteIndex, NcPlane,
 };
 
 const NCBOXLIGHT: &str = "┌┐└┘─│";
@@ -18,38 +19,102 @@ const NCBOXDOUBLE: &str = "╔╗╚╝═║";
 const NCBOXASCII: &str = "/\\\\/-|";
 const NCBOXOUTER: &str = "🭽🭾🭼🭿▁🭵🭶🭰";
 
+// Channels -----------------------------------------------------------------------
+
+/// Gets the background alpha and coloring bits from the cell [`NcChannels_u64`]
+/// as an [`NcChannel_u32`].
+///
+/// *Method: NcCell.[bchannel()][NcCell#method.bchannel].*
+#[inline]
+pub fn nccell_bchannel(cell: &NcCell) -> NcChannel_u32 {
+    c_api::ncchannels_bchannel(cell.channels)
+}
+
+/// Gets the foreground alpha and coloring bits from the cell [`NcChannels_u64`]
+/// as an [`NcChannel_u32`].
+///
+/// *Method: NcCell.[fchannel()][NcCell#method.fchannel].*
+#[inline]
+pub fn nccell_fchannel(cell: &NcCell) -> NcChannel_u32 {
+    c_api::ncchannels_fchannel(cell.channels)
+}
+
+/// Gets the alpha and coloring bits from the cell [`NcChannels_u64`].
+///
+/// *Method: NcCell.[channels()][NcCell#method.channels].*
+#[inline]
+pub fn nccell_channels(cell: &NcCell) -> NcChannels_u64 {
+    c_api::ncchannels_channels(cell.channels)
+}
+
+/// Sets the background alpha and coloring bits of the cell from an [`NcChannel_u32`],
+/// returning the new [`NcChannels_u64`].
+///
+/// *Method: NcCell.[set_bchannel()][NcCell#method.set_bchannel].*
+#[inline]
+pub fn nccell_set_bchannel(
+    cell: &mut NcCell,
+    bchannel: impl Into<NcChannel_u32>,
+) -> NcChannels_u64 {
+    c_api::ncchannels_set_bchannel(&mut cell.channels, bchannel.into())
+}
+
+/// Sets the foreground alpha and coloring bits of the cell from an [`NcChannel_u32`],
+/// returning the new [`NcChannels_u64`].
+///
+/// *Method: NcCell.[set_fchannel()][NcCell#method.set_fchannel].*
+#[inline]
+pub fn nccell_set_fchannel(
+    cell: &mut NcCell,
+    fchannel: impl Into<NcChannel_u32>,
+) -> NcChannels_u64 {
+    c_api::ncchannels_set_fchannel(&mut cell.channels, fchannel.into())
+}
+
+/// Sets the alpha and coloring bits of the cell from an [`NcChannels_u64`],
+/// returning the new [`NcChannels_u64`].
+///
+/// *Method: NcCell.[set_fchannel()][NcCell#method.set_fchannel].*
+#[inline]
+pub fn nccell_set_channels(
+    cell: &mut NcCell,
+    channels: impl Into<NcChannels_u64>,
+) -> NcChannels_u64 {
+    c_api::ncchannels_set_channels(&mut cell.channels, channels.into())
+}
+
 // Alpha -----------------------------------------------------------------------
 
-/// Extracts the foreground [`NcAlpha`] from an [`NcCell`] (shifted to LSBs).
+/// Gets the foreground [`NcAlpha_u32`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[fg_alpha()][NcCell#method.fg_alpha].*
 #[inline]
-pub fn nccell_fg_alpha(cell: &NcCell) -> NcAlpha {
+pub fn nccell_fg_alpha(cell: &NcCell) -> NcAlpha_u32 {
     c_api::ncchannels_fg_alpha(cell.channels)
 }
 
-/// Extracts the background [`NcAlpha`] from an [`NcCell`] (shifted to LSBs).
+/// Gets the background [`NcAlpha_u32`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[bg_alpha()][NcCell#method.bg_alpha].*
 #[inline]
-pub fn nccell_bg_alpha(cell: &NcCell) -> NcAlpha {
+pub fn nccell_bg_alpha(cell: &NcCell) -> NcAlpha_u32 {
     c_api::ncchannels_bg_alpha(cell.channels)
 }
 
-/// Sets the foreground [`NcAlpha`] of an [`NcCell`].
+/// Sets the foreground [`NcAlpha_u32`] of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_fg_alpha()][NcCell#method.set_fg_alpha].*
 #[inline]
-pub fn nccell_set_fg_alpha(cell: &mut NcCell, alpha: NcAlpha) {
-    c_api::ncchannels_set_fg_alpha(&mut cell.channels, alpha);
+pub fn nccell_set_fg_alpha(cell: &mut NcCell, alpha: impl Into<NcAlpha_u32>) {
+    c_api::ncchannels_set_fg_alpha(&mut cell.channels, alpha.into());
 }
 
-/// Sets the background [`NcAlpha`] of an [`NcCell`].
+/// Sets the background [`NcAlpha_u32`] of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_bg_alpha()][NcCell#method.set_bg_alpha].*
 #[inline]
-pub fn nccell_set_bg_alpha(cell: &mut NcCell, alpha: NcAlpha) {
-    c_api::ncchannels_set_bg_alpha(&mut cell.channels, alpha);
+pub fn nccell_set_bg_alpha(cell: &mut NcCell, alpha: impl Into<NcAlpha_u32>) {
+    c_api::ncchannels_set_bg_alpha(&mut cell.channels, alpha.into());
 }
 
 // u8 ---------------------------------------------------------------------
@@ -57,7 +122,7 @@ pub fn nccell_set_bg_alpha(cell: &mut NcCell, alpha: NcAlpha) {
 /// Gets the foreground components of an [`NcCell`],
 /// and returns the [`NcChannel_u32`] (which can have some extra bits set).
 ///
-/// *Method: NcCell.[fg_rgb8()][NcCell#method.fg_rgb8].*
+/// *Method: NcCell.[fg_rgb()][NcCell#method.fg_rgb].*
 #[inline]
 pub fn nccell_fg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8) -> NcChannel_u32 {
     c_api::ncchannels_fg_rgb8(cell.channels, red, green, blue)
@@ -66,7 +131,7 @@ pub fn nccell_fg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8
 /// Gets the background components of an [`NcCell`],
 /// and returns the [`NcChannel_u32`] (which can have some extra bits set).
 ///
-/// *Method: NcCell.[bg_rgb8()][NcCell#method.bg_rgb8].*
+/// *Method: NcCell.[bg_rgb()][NcCell#method.bg_rgb].*
 #[inline]
 pub fn nccell_bg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8) -> NcChannel_u32 {
     c_api::ncchannels_bg_rgb8(cell.channels, red, green, blue)
@@ -75,7 +140,7 @@ pub fn nccell_bg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8
 /// Sets the foreground components of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
-/// *Method: NcCell.[set_fg_rgb8()][NcCell#method.set_fg_rgb8].*
+/// *Method: NcCell.[set_fg_rgb()][NcCell#method.set_fg_rgb].*
 #[inline]
 pub fn nccell_set_fg_rgb8(cell: &mut NcCell, red: u8, green: u8, blue: u8) {
     c_api::ncchannels_set_fg_rgb8(&mut cell.channels, red, green, blue);
@@ -84,7 +149,7 @@ pub fn nccell_set_fg_rgb8(cell: &mut NcCell, red: u8, green: u8, blue: u8) {
 /// Sets the background components of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
-/// *Method: NcCell.[set_bg_rgb8()][NcCell#method.set_bg_rgb8].*
+/// *Method: NcCell.[set_bg_rgb()][NcCell#method.set_bg_rgb].*
 #[inline]
 pub fn nccell_set_bg_rgb8(cell: &mut NcCell, red: u8, green: u8, blue: u8) {
     c_api::ncchannels_set_bg_rgb8(&mut cell.channels, red, green, blue);
@@ -113,8 +178,8 @@ pub fn nccell_bg_rgb(cell: &NcCell) -> NcRgb_u32 {
 ///
 /// *Method: NcCell.[set_fg_rgb()][NcCell#method.set_fg_rgb].*
 #[inline]
-pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: NcRgb_u32) {
-    c_api::ncchannels_set_fg_rgb(&mut cell.channels, rgb);
+pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: impl Into<NcRgb_u32>) {
+    c_api::ncchannels_set_fg_rgb(&mut cell.channels, rgb.into());
 }
 
 /// Sets the background [`NcRgb_u32`] of an [`NcCell`],
@@ -122,8 +187,8 @@ pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: NcRgb_u32) {
 ///
 /// *Method: NcCell.[set_bg_rgb()][NcCell#method.set_bg_rgb].*
 #[inline]
-pub fn nccell_set_bg_rgb(cell: &mut NcCell, rgb: NcRgb_u32) {
-    c_api::ncchannels_set_bg_rgb(&mut cell.channels, rgb);
+pub fn nccell_set_bg_rgb(cell: &mut NcCell, rgb: impl Into<NcRgb_u32>) {
+    c_api::ncchannels_set_bg_rgb(&mut cell.channels, rgb.into());
 }
 
 // Default ---------------------------------------------------------------------
@@ -207,35 +272,41 @@ pub const fn nccell_bg_palindex(cell: &NcCell) -> NcPaletteIndex {
 
 /// Sets an [`NcCell`]'s foreground [`NcPaletteIndex`].
 ///
-/// Also sets [`NcChannels_u64::FG_PALETTE`][NcChannels_u64#associatedconstant.FG_PALETTE]
-/// and [`NcAlpha::OPAQUE`][NcAlpha#associatedconstant::OPAQUE], and clears out
-/// [`NcChannels_u64::FG_DEFAULT_MASK`][NcChannels_u64#associatedconstant.FG_DEFAULT_MASK].
+/// Also sets [`NcChannels_u64::FG_PALETTE`] and [`NCALPHA_OPAQUE`],
+/// and clears out [`NcChannels_u64::FG_DEFAULT_MASK`].
 ///
 /// Note: Unlike the original C function, this one can't fail.
 ///
+/// [`NCALPHA_OPAQUE`]: c_api::NCALPHA_OPAQUE
+/// [`NcChannels_u64::FG_PALETTE`]: NcChannels_u64#associatedconstant.FG_PALETTE
+/// [`NcChannels_u64::FG_DEFAULT_MASK`]: NcChannels_u64#associatedconstant.FG_DEFAULT_MASK
+///
 /// *Method: NcCell.[set_fg_palindex()][NcCell#method.set_fg_palindex].*
 #[inline]
-pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    c_api::ncchannels_set_fg_palindex(&mut cell.channels, index)
+pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: impl Into<NcPaletteIndex>) {
+    c_api::ncchannels_set_fg_palindex(&mut cell.channels, index.into())
 }
 
 /// Sets an [`NcCell`]'s background [`NcPaletteIndex`].
 ///
-/// Also sets [`NcChannels_u64::BG_PALETTE`][NcChannels_u64#associatedconstant.BG_PALETTE]
-/// and [`NcAlpha::OPAQUE`][NcAlpha#associatedconstant::OPAQUE], and clears out
-/// [`NcChannels_u64::BG_DEFAULT_MASK`][NcChannels_u64#associatedconstant.BG_DEFAULT_MASK].
+/// Also sets [`NcChannels_u64::BG_PALETTE`] and [`NCALPHA_OPAQUE`],
+/// and clears out [`NcChannels_u64::BG_DEFAULT_MASK`].
 ///
 /// Note: Unlike the original C function, this one can't fail.
 ///
+/// [`NCALPHA_OPAQUE`]: c_api::NCALPHA_OPAQUE
+/// [`NcChannels_u64::BG_PALETTE`]: NcChannels_u64#associatedconstant.BG_PALETTE
+/// [`NcChannels_u64::BG_DEFAULT_MASK`]: NcChannels_u64#associatedconstant.BG_DEFAULT_MASK
+///
 /// *Method: NcCell.[set_bg_palindex()][NcCell#method.set_bg_palindex].*
 #[inline]
-pub fn nccell_set_bg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    c_api::ncchannels_set_bg_palindex(&mut cell.channels, index)
+pub fn nccell_set_bg_palindex(cell: &mut NcCell, index: impl Into<NcPaletteIndex>) {
+    c_api::ncchannels_set_bg_palindex(&mut cell.channels, index.into())
 }
 
 // Styles ----------------------------------------------------------------------
 
-/// Extracts the [`NcStyle_u16`] bits from an [`NcCell`].
+/// Gets the [`NcStyle_u16`] bits from an [`NcCell`].
 ///
 /// *Method: NcCell.[cell_styles()][NcCell#method.cell_styles].*
 #[inline]
@@ -248,16 +319,16 @@ pub const fn nccell_styles(cell: &NcCell) -> NcStyle_u16 {
 ///
 /// *Method: NcCell.[styles_on()][NcCell#method.styles_on].*
 #[inline]
-pub fn nccell_on_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
-    cell.stylemask |= stylebits & c_api::NCSTYLE_MASK as u16;
+pub fn nccell_on_styles(cell: &mut NcCell, stylebits: impl Into<NcStyle_u16>) {
+    cell.stylemask |= stylebits.into() & c_api::NCSTYLE_MASK as u16;
 }
 
 /// Removes the specified [`NcStyle_u16`] bits from an [`NcCell`]'s existing spec.
 ///
 /// *Method: NcCell.[styles_off()][NcCell#method.styles_off].*
 #[inline]
-pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
-    cell.stylemask &= !(stylebits & c_api::NCSTYLE_MASK as u16);
+pub fn nccell_off_styles(cell: &mut NcCell, stylebits: impl Into<NcStyle_u16>) {
+    cell.stylemask &= !(stylebits.into() & c_api::NCSTYLE_MASK as u16);
 }
 
 /// Sets *just* the specified [`NcStyle_u16`] bits for an [`NcCell`],
@@ -265,8 +336,8 @@ pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
 ///
 /// *Method: NcCell.[styles_set()][NcCell#method.styles_set].*
 #[inline]
-pub fn nccell_set_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
-    cell.stylemask = stylebits & c_api::NCSTYLE_MASK as u16;
+pub fn nccell_set_styles(cell: &mut NcCell, stylebits: impl Into<NcStyle_u16>) {
+    cell.stylemask = stylebits.into() & c_api::NCSTYLE_MASK as u16;
 }
 
 // Chars -----------------------------------------------------------------------
@@ -382,12 +453,13 @@ pub fn nccell_prime(
     plane: &mut NcPlane,
     cell: &mut NcCell,
     gcluster: &str,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
 ) -> NcResult_i32 {
-    cell.stylemask = style;
-    cell.channels = channels;
-    unsafe { c_api::nccell_load(plane, cell, cstring![gcluster]) }
+    cell.stylemask = style.into();
+    cell.channels = channels.into();
+    let cs = cstring![gcluster];
+    unsafe { c_api::nccell_load(plane, cell, cs.as_ptr()) }
 }
 
 /// Loads up six cells with the `EGC`s necessary to draw a box.
@@ -402,8 +474,8 @@ pub fn nccell_prime(
 #[inline]
 pub fn nccells_load_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16> + Copy,
+    channels: impl Into<NcChannels_u64> + Copy,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -414,32 +486,32 @@ pub fn nccells_load_box(
 ) -> NcResult_i32 {
     assert![gcluster.len() >= 6]; // DEBUG
 
-    // TODO: CHECK: mutable copy for pointer arithmetics:
-    let mut gclu = cstring![gcluster];
+    // CHECK: mutable copy for pointer arithmetics
 
-    let mut ulen: NcResult_i32;
+    let cs = cstring![gcluster];
+    let mut gclu = cs.as_ptr();
 
-    ulen = nccell_prime(plane, ul, gcluster, style, channels);
+    let mut ulen: NcResult_i32 = nccell_prime(plane, ul, gcluster, style.into(), channels.into());
 
     if ulen > 0 {
         gclu = unsafe { gclu.offset(ulen as isize) };
-        ulen = nccell_prime(plane, ur, gcluster, style, channels);
+        ulen = nccell_prime(plane, ur, gcluster, style.into(), channels.into());
 
         if ulen > 0 {
             gclu = unsafe { gclu.offset(ulen as isize) };
-            ulen = nccell_prime(plane, ll, gcluster, style, channels);
+            ulen = nccell_prime(plane, ll, gcluster, style.into(), channels.into());
 
             if ulen > 0 {
                 gclu = unsafe { gclu.offset(ulen as isize) };
-                ulen = nccell_prime(plane, lr, gcluster, style, channels);
+                ulen = nccell_prime(plane, lr, gcluster, style.into(), channels.into());
 
                 if ulen > 0 {
                     gclu = unsafe { gclu.offset(ulen as isize) };
-                    ulen = nccell_prime(plane, hl, gcluster, style, channels);
+                    ulen = nccell_prime(plane, hl, gcluster, style.into(), channels.into());
 
                     if ulen > 0 {
                         let _gclu = unsafe { gclu.offset(ulen as isize) };
-                        ulen = nccell_prime(plane, vl, gcluster, style, channels);
+                        ulen = nccell_prime(plane, vl, gcluster, style.into(), channels.into());
 
                         if ulen > 0 {
                             return c_api::NCRESULT_OK;
@@ -473,8 +545,8 @@ pub fn nccells_load_box(
 #[inline]
 pub fn nccells_ascii_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -482,7 +554,18 @@ pub fn nccells_ascii_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
 ) -> NcResult_i32 {
-    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXASCII)
+    nccells_load_box(
+        plane,
+        style.into(),
+        channels.into(),
+        ul,
+        ur,
+        ll,
+        lr,
+        hl,
+        vl,
+        NCBOXASCII,
+    )
 }
 
 /// [`nccells_load_box`] with double line box-drawing characters.
@@ -491,8 +574,8 @@ pub fn nccells_ascii_box(
 #[inline]
 pub fn nccells_double_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -500,7 +583,18 @@ pub fn nccells_double_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
 ) -> NcResult_i32 {
-    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXDOUBLE)
+    nccells_load_box(
+        plane,
+        style.into(),
+        channels.into(),
+        ul,
+        ur,
+        ll,
+        lr,
+        hl,
+        vl,
+        NCBOXDOUBLE,
+    )
 }
 
 /// [`nccells_load_box`] with heavy line box-drawing characters.
@@ -509,8 +603,8 @@ pub fn nccells_double_box(
 #[inline]
 pub fn nccells_heavy_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -518,7 +612,18 @@ pub fn nccells_heavy_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
 ) -> NcResult_i32 {
-    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXHEAVY)
+    nccells_load_box(
+        plane,
+        style.into(),
+        channels.into(),
+        ul,
+        ur,
+        ll,
+        lr,
+        hl,
+        vl,
+        NCBOXHEAVY,
+    )
 }
 
 /// [`nccells_load_box`] with light line box-drawing characters.
@@ -527,8 +632,8 @@ pub fn nccells_heavy_box(
 #[inline]
 pub fn nccells_light_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -536,7 +641,18 @@ pub fn nccells_light_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
 ) -> NcResult_i32 {
-    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXLIGHT)
+    nccells_load_box(
+        plane,
+        style.into(),
+        channels.into(),
+        ul,
+        ur,
+        ll,
+        lr,
+        hl,
+        vl,
+        NCBOXLIGHT,
+    )
 }
 
 /// [`nccells_load_box`] with round line box-drawing characters.
@@ -545,8 +661,8 @@ pub fn nccells_light_box(
 #[inline]
 pub fn nccells_rounded_box(
     plane: &mut NcPlane,
-    style: NcStyle_u16,
-    channels: NcChannels_u64,
+    style: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -554,5 +670,16 @@ pub fn nccells_rounded_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
 ) -> NcResult_i32 {
-    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXROUND)
+    nccells_load_box(
+        plane,
+        style.into(),
+        channels.into(),
+        ul,
+        ur,
+        ll,
+        lr,
+        hl,
+        vl,
+        NCBOXROUND,
+    )
 }
