@@ -104,6 +104,37 @@ mod std_impls {
     crate::from_primitive![NcChannels, NcChannels_u64];
     crate::unit_impl_from![NcChannels, NcChannels_u64];
     crate::unit_impl_fmt![bases+display; NcChannels];
+
+    // Different background and foreground:
+
+    impl From<NcChannels> for [u8; 6] {
+        #[inline]
+        fn from(rgb: NcChannels) -> Self {
+            let fg: (u8, u8, u8) = rgb.fg_rgb().into();
+            let bg: (u8, u8, u8) = rgb.bg_rgb().into();
+            [fg.0, fg.1, fg.2, bg.0, bg.1, bg.2]
+        }
+    }
+    impl From<[u8; 6]> for NcChannels {
+        #[inline]
+        fn from(a: [u8; 6]) -> Self {
+            Self::from_rgb((a[0], a[1], a[2]), (a[3], a[4], a[5]))
+        }
+    }
+
+    impl From<NcChannels> for (u8, u8, u8, u8, u8, u8) {
+        #[inline]
+        fn from(rgb: NcChannels) -> Self {
+            let fg: (u8, u8, u8) = rgb.fg_rgb().into();
+            let bg: (u8, u8, u8) = rgb.bg_rgb().into();
+            (fg.0, fg.1, fg.2, bg.0, bg.1, bg.2)
+        }
+    }
+    impl From<(u8, u8, u8, u8, u8, u8)> for NcChannels {
+        fn from(t: (u8, u8, u8, u8, u8, u8)) -> Self {
+            Self::from_rgb([t.0, t.1, t.2], [t.3, t.4, t.5])
+        }
+    }
 }
 
 /// # NcChannels constants
@@ -127,6 +158,11 @@ impl NcChannels {
 
     /// Extract these bits to get the background [`NcRgb`][crate::NcRgb] value.
     pub const BG_RGB_MASK: u32 = super::c_api::NC_BG_RGB_MASK;
+
+    /// Does this glyph completely obscure the background? If so, there's no need
+    /// to emit a background when rasterizing, a small optimization. These are
+    /// also used to track regions into which we must not cellblit.
+    pub const NOBACKGROUND_MASK: u64 = c_api::NC_NOBACKGROUND_MASK;
 }
 
 /// # NcChannels constructors
@@ -143,33 +179,25 @@ impl NcChannels {
 
     /// New `NcChannels`, expects two separate [`NcRgb`]s for the foreground
     /// and background channels.
-    pub fn from_rgb<RGB1, RGB2>(fg_rgb: RGB1, bg_rgb: RGB2) -> Self
-    where
-        RGB1: Into<NcRgb>,
-        RGB2: Into<NcRgb>,
-    {
+    pub fn from_rgb(fg_rgb: impl Into<NcRgb>, bg_rgb: impl Into<NcRgb>) -> Self {
         Self::combine(NcChannel::from_rgb(fg_rgb), NcChannel::from_rgb(bg_rgb))
     }
 
     /// New `NcChannels`, expects a single [`NcRgb`] for both foreground
     /// and background channels.
-    pub fn from_rgb_both<RGB: Into<NcRgb>>(rgb: RGB) -> Self {
+    pub fn from_rgb_both(rgb: impl Into<NcRgb>) -> Self {
         let channel = NcChannel::new().set(rgb.into());
         Self::combine(channel, channel)
     }
 
     /// New `NcChannels`, expects two separate [`NcRgb`] & [`NcAlpha`] for the
     /// foreground and background channels.
-    pub fn from_rgb_alpha<RGB1, RGB2>(
-        fg_rgb: RGB1,
-        fg_alpha: NcAlpha,
-        bg_rgb: RGB2,
-        bg_alpha: NcAlpha,
-    ) -> Self
-    where
-        RGB1: Into<NcRgb>,
-        RGB2: Into<NcRgb>,
-    {
+    pub fn from_rgb_alpha(
+        fg_rgb: impl Into<NcRgb>,
+        fg_alpha: impl Into<NcAlpha>,
+        bg_rgb: impl Into<NcRgb>,
+        bg_alpha: impl Into<NcAlpha>,
+    ) -> Self {
         Self::combine(
             NcChannel::from_rgb(fg_rgb).set_alpha(fg_alpha),
             NcChannel::from_rgb(bg_rgb).set_alpha(bg_alpha),
@@ -178,48 +206,8 @@ impl NcChannels {
 
     /// New `NcChannels`, expects [`NcRgb`] & [`NcAlpha`] for both
     /// channels.
-    pub fn from_rgb_alpha_both<RGB: Into<NcRgb>>(rgb: RGB, alpha: NcAlpha) -> Self {
-        let channel = NcChannel::new().set(rgb.into()).set_alpha(alpha);
-        Self::combine(channel, channel)
-    }
-
-    /// New `NcChannels`, expects three RGB component components
-    /// for each channel.
-    pub fn from_rgb8(fg_r: u8, fg_g: u8, fg_b: u8, bg_r: u8, bg_g: u8, bg_b: u8) -> Self {
-        Self::combine(
-            NcChannel::from_rgb8(fg_r, fg_g, fg_b),
-            NcChannel::from_rgb8(bg_r, bg_g, bg_b),
-        )
-    }
-
-    /// New `NcChannels`, expects three RGB component components for
-    /// both the foreground and background channels.
-    pub fn from_rgb8_both(r: u8, g: u8, b: u8) -> Self {
-        let channel = NcChannel::new().set_rgb8(r, g, b);
-        Self::combine(channel, channel)
-    }
-
-    /// New `NcChannels`, expects three RGB components and
-    /// [`NcAlpha`], for both the foreground and background channels.
-    pub fn from_rgb8_alpha(
-        fg_r: u8,
-        fg_g: u8,
-        fg_b: u8,
-        fg_alpha: NcAlpha,
-        bg_r: u8,
-        bg_g: u8,
-        bg_b: u8,
-        bg_alpha: NcAlpha,
-    ) -> Self {
-        Self::combine(
-            NcChannel::from_rgb8_alpha(fg_r, fg_g, fg_b, fg_alpha),
-            NcChannel::from_rgb8_alpha(bg_r, bg_g, bg_b, bg_alpha),
-        )
-    }
-
-    /// New `NcChannel`, expects three RGB components.
-    pub fn from_rgb8_alpha_both(r: u8, g: u8, b: u8, alpha: NcAlpha) -> Self {
-        let channel = NcChannel::new().set_rgb8(r, g, b).set_alpha(alpha);
+    pub fn from_rgb_alpha_both(rgb: impl Into<NcRgb>, alpha: impl Into<NcAlpha>) -> Self {
+        let channel = NcChannel::new().set(rgb.into()).set_alpha(alpha.into());
         Self::combine(channel, channel)
     }
 
@@ -228,8 +216,8 @@ impl NcChannels {
     /// Combines two [`NcChannel`]s into an [`NcChannels`].
     ///
     /// *C style function: [channels_combine()][c_api::ncchannels_combine].*
-    pub fn combine(fchannel: NcChannel, bchannel: NcChannel) -> Self {
-        c_api::ncchannels_combine(fchannel.0, bchannel.0).into()
+    pub fn combine(fchannel: impl Into<NcChannel>, bchannel: impl Into<NcChannel>) -> Self {
+        c_api::ncchannels_combine(fchannel.into().0, bchannel.into().0).into()
     }
 
     /// Returns the `NcChannels` with the fore- and background's color
@@ -255,32 +243,47 @@ impl NcChannels {
 impl NcChannels {
     // NcChannel
 
-    /// Extracts the foreground [`NcChannel`].
+    /// Gets the foreground alpha and coloring bits as an [`NcChannel`].
     ///
     /// *C style function: [ncchannels_fchannel()][c_api::ncchannels_fchannel].*
     pub fn fchannel(&self) -> NcChannel {
         c_api::ncchannels_fchannel(self.0).into()
     }
 
-    /// Extracts the background [`NcChannel`].
+    /// Gets the background alpha and coloring bits as an [`NcChannel`].
     ///
     /// *C style function: [ncchannels_bchannel()][c_api::ncchannels_bchannel].*
     pub fn bchannel(&self) -> NcChannel {
         c_api::ncchannels_bchannel(self.0).into()
     }
 
-    /// Sets the foreground [`NcChannel`].
+    /// Sets the foreground alpha and coloring bits from an [`NcChannel`].
     ///
     /// *C style function: [ncchannels_set_fchannel()][c_api::ncchannels_set_fchannel].*
-    pub fn set_fchannel(&mut self, fchannel: NcChannel) -> Self {
-        c_api::ncchannels_set_fchannel(&mut self.0, fchannel.0).into()
+    pub fn set_fchannel(&mut self, fchannel: impl Into<NcChannel>) -> Self {
+        c_api::ncchannels_set_fchannel(&mut self.0, fchannel.into().0).into()
     }
 
-    /// Sets the background [`NcChannel`].
+    /// Sets the background alpha and coloring bits from an [`NcChannel`].
     ///
     /// *C style function: [ncchannels_set_bchannel()][c_api::ncchannels_set_bchannel].*
-    pub fn set_bchannel(&mut self, bchannel: NcChannel) -> Self {
-        c_api::ncchannels_set_bchannel(&mut self.0, bchannel.0).into()
+    pub fn set_bchannel(&mut self, bchannel: impl Into<NcChannel>) -> Self {
+        c_api::ncchannels_set_bchannel(&mut self.0, bchannel.into().0).into()
+    }
+
+    /// Gets the alpha and coloring bits as an [`NcChannels`].
+    ///
+    /// *C style function: [ncchannels_bchannel()][c_api::ncchannels_bchannel].*
+    pub fn channels(&self) -> NcChannels {
+        c_api::ncchannels_channels(self.0).into()
+    }
+
+    /// Sets the foreground alpha and coloring bits as an [`NcChannels`],
+    /// from another [`NcChannels`].
+    ///
+    /// *C style function: [ncchannels_set_fchannel()][c_api::ncchannels_set_fchannel].*
+    pub fn set_channels(&mut self, from_channels: impl Into<NcChannels>) -> Self {
+        c_api::ncchannels_set_channels(&mut self.0, from_channels.into().0).into()
     }
 
     // Alpha
@@ -289,28 +292,28 @@ impl NcChannels {
     ///
     /// *C style function: [ncchannels_fg_alpha()][c_api::ncchannels_fg_alpha].*
     pub fn fg_alpha(&self) -> NcAlpha {
-        c_api::ncchannels_fg_alpha(self.0)
+        c_api::ncchannels_fg_alpha(self.0).into()
     }
 
     /// Gets the background [`NcAlpha`].
     ///
     /// *C style function: [ncchannels_bg_alpha()][c_api::ncchannels_bg_alpha].*
     pub fn bg_alpha(&self) -> NcAlpha {
-        c_api::ncchannels_bg_alpha(self.0)
+        c_api::ncchannels_bg_alpha(self.0).into()
     }
 
     /// Sets the foreground [`NcAlpha`].
     ///
     /// *C style function: [ncchannels_set_fg_alpha()][c_api::ncchannels_set_fg_alpha].*
-    pub fn set_fg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
-        error![c_api::ncchannels_set_fg_alpha(&mut self.0, alpha)]
+    pub fn set_fg_alpha(&mut self, alpha: impl Into<NcAlpha>) -> NcResult<()> {
+        error![c_api::ncchannels_set_fg_alpha(&mut self.0, alpha.into())]
     }
 
     /// Sets the background [`NcAlpha`].
     ///
     /// *C style function: [ncchannels_set_bg_alpha()][c_api::ncchannels_set_bg_alpha].*
-    pub fn set_bg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
-        error![c_api::ncchannels_set_bg_alpha(&mut self.0, alpha)]
+    pub fn set_bg_alpha(&mut self, alpha: impl Into<NcAlpha>) -> NcResult<()> {
+        error![c_api::ncchannels_set_bg_alpha(&mut self.0, alpha.into())]
     }
 
     // NcRgb
@@ -346,55 +349,19 @@ impl NcChannels {
     /// Sets the foreground [`NcRgb`].
     ///
     /// *C style function: [channels_set_fg_rgb()][c_api::ncchannels_set_fg_rgb].*
-    pub fn set_fg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) -> Self {
-        c_api::ncchannels_set_fg_rgb(&mut self.0, rgb.into().into());
+    pub fn set_fg_rgb(&mut self, rgb: impl Into<NcRgb>) -> Self {
+        c_api::ncchannels_set_fg_rgb(&mut self.0, rgb.into().0);
         *self
     }
 
     /// Sets the background [`NcRgb`].
     ///
     /// *C style function: [channels_set_bg_rgb()][c_api::ncchannels_set_bg_rgb].*
-    pub fn set_bg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) -> Self {
-        c_api::ncchannels_set_bg_rgb(&mut self.0, rgb.into().into());
+    pub fn set_bg_rgb(&mut self, rgb: impl Into<NcRgb>) -> Self {
+        c_api::ncchannels_set_bg_rgb(&mut self.0, rgb.into().0);
         *self
     }
 
-    // u8
-
-    /// Gets the three foreground RGB components (r, g, b).
-    ///
-    /// *C style function: [channels_fg_rgb8()][c_api::ncchannels_fg_rgb8].*
-    pub fn fg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        c_api::ncchannels_fg_rgb8(self.0, &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
-    /// Gets the three background RGB components (r, g, b).
-    ///
-    /// *C style function: [channels_bg_rgb8()][c_api::ncchannels_bg_rgb8].*
-    pub fn bg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        c_api::ncchannels_bg_rgb8(self.0, &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
-    /// Sets the three foreground RGB components (r, g, b), and
-    /// marks the foreground [`NcChannel`] as not using the "default color".
-    ///
-    /// *C style function: [channels_set_fg_rgb8()][c_api::ncchannels_set_fg_rgb8].*
-    pub fn set_fg_rgb8(&mut self, r: u8, g: u8, b: u8) -> Self {
-        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g, b).into()
-    }
-
-    /// Sets the three background RGB components (r, g, b), and
-    /// marks the background [`NcChannel`] as not using the "default color".
-    ///
-    /// *C style function: [channels_set_bg_rgb8()][c_api::ncchannels_set_bg_rgb8].*
-    pub fn set_bg_rgb8(&mut self, r: u8, g: u8, b: u8) -> Self {
-        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g, b).into()
-    }
-
     /// Gets the foreground red component.
     ///
     /// *(No equivalent C style function)*
@@ -440,49 +407,49 @@ impl NcChannels {
     /// Sets the foreground red component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn fg_set_r(&mut self, r: u8) -> Self {
-        let (_, g, b) = self.bg_rgb8();
-        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g, b).into()
+    pub fn fg_set_r(&mut self, r: impl Into<u8>) -> Self {
+        let (_, g, b) = self.bg_rgb().into();
+        c_api::ncchannels_set_fg_rgb8(&mut self.0, r.into(), g, b).into()
     }
 
     /// Sets the foreground green component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn fg_set_g(&mut self, g: u8) -> Self {
-        let (r, _, b) = self.bg_rgb8();
-        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g, b).into()
+    pub fn fg_set_g(&mut self, g: impl Into<u8>) -> Self {
+        let (r, _, b) = self.bg_rgb().into();
+        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g.into(), b).into()
     }
 
     /// Sets the foreground blue component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn fg_set_b(&mut self, b: u8) -> Self {
-        let (r, g, _) = self.bg_rgb8();
-        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g, b).into()
+    pub fn fg_set_b(&mut self, b: impl Into<u8>) -> Self {
+        let (r, g, _) = self.bg_rgb().into();
+        c_api::ncchannels_set_fg_rgb8(&mut self.0, r, g, b.into()).into()
     }
 
     /// Sets the background red component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn bg_set_r(&mut self, r: u8) -> Self {
-        let (_, g, b) = self.bg_rgb8();
-        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g, b).into()
+    pub fn bg_set_r(&mut self, r: impl Into<u8>) -> Self {
+        let (_, g, b) = self.bg_rgb().into();
+        c_api::ncchannels_set_bg_rgb8(&mut self.0, r.into(), g, b).into()
     }
 
     /// Sets the background green component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn bg_set_g(&mut self, g: u8) -> Self {
-        let (r, _, b) = self.bg_rgb8();
-        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g, b).into()
+    pub fn bg_set_g(&mut self, g: impl Into<u8>) -> Self {
+        let (r, _, b) = self.bg_rgb().into();
+        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g.into(), b).into()
     }
 
     /// Sets the background blue component, and returns the new `NcChannels`.
     ///
     /// *(No equivalent C style function)*
-    pub fn bg_set_b(&mut self, b: u8) -> Self {
-        let (r, g, _) = self.bg_rgb8();
-        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g, b).into()
+    pub fn bg_set_b(&mut self, b: impl Into<u8>) -> Self {
+        let (r, g, _) = self.bg_rgb().into();
+        c_api::ncchannels_set_bg_rgb8(&mut self.0, r, g, b.into()).into()
     }
 
     // default color
@@ -561,14 +528,14 @@ impl NcChannels {
 
     // NcPaletteIndex
 
-    /// Extracts the [`NcPaletteIndex`] from the foreground [`NcChannel`].
+    /// Gets the [`NcPaletteIndex`] from the foreground [`NcChannel`].
     ///
     /// *C style function: [channels_fg_palindex()][c_api::ncchannels_fg_palindex].*
     pub fn fg_palindex(&self) -> NcPaletteIndex {
         c_api::ncchannels_fg_palindex(self.0)
     }
 
-    /// Extracts the [`NcPaletteIndex`] from the background [`NcChannel`].
+    /// Gets the [`NcPaletteIndex`] from the background [`NcChannel`].
     ///
     /// *C style function: [channels_bg_palindex()][c_api::ncchannels_bg_palindex].*
     pub fn bg_palindex(&self) -> NcPaletteIndex {
@@ -595,8 +562,8 @@ impl NcChannels {
     /// [*indexed*][NcPaletteIndex] [`NcPalette`][crate::NcPalette] color.
     ///
     /// *C style function: [channels_set_fg_palindex()][c_api::ncchannels_set_fg_palindex].*
-    pub fn set_fg_palindex(&mut self, index: NcPaletteIndex) -> Self {
-        c_api::ncchannels_set_fg_palindex(&mut self.0, index);
+    pub fn set_fg_palindex(&mut self, index: impl Into<NcPaletteIndex>) -> Self {
+        c_api::ncchannels_set_fg_palindex(&mut self.0, index.into());
         *self
     }
 
@@ -604,13 +571,8 @@ impl NcChannels {
     /// [*indexed*][NcPaletteIndex] [`NcPalette`][crate::NcPalette] color.
     ///
     /// *C style function: [channels_set_bg_palindex()][c_api::ncchannels_set_bg_palindex].*
-    pub fn set_bg_palindex(&mut self, index: NcPaletteIndex) -> Self {
-        c_api::ncchannels_set_bg_palindex(&mut self.0, index);
+    pub fn set_bg_palindex(&mut self, index: impl Into<NcPaletteIndex>) -> Self {
+        c_api::ncchannels_set_bg_palindex(&mut self.0, index.into());
         *self
     }
-
-    /// Does this glyph completely obscure the background? If so, there's no need
-    /// to emit a background when rasterizing, a small optimization. These are
-    /// also used to track regions into which we must not cellblit.
-    pub const NOBACKGROUND_MASK: u64 = c_api::NC_NOBACKGROUND_MASK;
 }
