@@ -4,8 +4,8 @@ use core::ptr::{null, null_mut};
 
 use crate::{
     c_api, cstring, error, error_ref_mut, rstring_free, NcAlign, NcBlitter, NcCapabilities,
-    NcChannels, NcDirect, NcDirectFlags, NcError, NcInput, NcPaletteIndex, NcPlane, NcResult,
-    NcRgb, NcScale, NcStyle, NcTime,
+    NcChannels, NcDirect, NcDirectFlag, NcError, NcInput, NcPaletteIndex, NcPlane, NcResult, NcRgb,
+    NcScale, NcStyle, NcTime,
 };
 
 /// # `NcDirect` constructors and destructors
@@ -26,7 +26,7 @@ impl NcDirect {
     ///
     /// *C style function: [ncdirect_init()][c_api::ncdirect_init].*
     pub unsafe fn new<'a>() -> NcResult<&'a mut NcDirect> {
-        Self::with_flags(NcDirectFlags::None)
+        Self::with_flags(NcDirectFlag::None)
     }
 
     /// New `NcDirect` with optional flags.
@@ -37,8 +37,8 @@ impl NcDirect {
     /// before creating a new one.
     ///
     /// *C style function: [ncdirect_init()][c_api::ncdirect_init].*
-    pub unsafe fn with_flags<'a>(flags: NcDirectFlags) -> NcResult<&'a mut NcDirect> {
-        let res = c_api::ncdirect_init(null(), null_mut(), flags.into());
+    pub unsafe fn with_flags<'a>(flags: impl Into<NcDirectFlag>) -> NcResult<&'a mut NcDirect> {
+        let res = c_api::ncdirect_init(null(), null_mut(), flags.into().into());
         error_ref_mut![res, "Initializing NcDirect"]
     }
 
@@ -73,9 +73,9 @@ impl NcDirect {
     /// and writes it to the output.
     ///
     /// *C style function: [ncdirect_raster_frame()][c_api::ncdirect_raster_frame].*
-    pub fn raster_frame(&mut self, frame: &mut NcPlane, align: NcAlign) -> NcResult<()> {
+    pub fn raster_frame(&mut self, frame: &mut NcPlane, align: impl Into<NcAlign>) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_raster_frame(self, frame, align.into()) },
+            unsafe { c_api::ncdirect_raster_frame(self, frame, align.into().into()) },
             "NcDirect.raster_frame()"
         ]
     }
@@ -95,17 +95,18 @@ impl NcDirect {
     pub fn render_frame<'a>(
         &mut self,
         filename: &str,
-        blitter: NcBlitter,
-        scale: NcScale,
+        blitter: impl Into<NcBlitter> + Copy,
+        scale: impl Into<NcScale> + Copy,
         max_y: u32,
         max_x: u32,
     ) -> NcResult<&'a mut NcPlane> {
+        let cs = cstring![filename];
         let res = unsafe {
             c_api::ncdirect_render_frame(
                 self,
-                cstring![filename],
-                blitter.into(),
-                scale.into(),
+                cs.as_ptr(),
+                blitter.into().into(),
+                scale.into().into(),
                 max_y as i32,
                 max_x as i32,
             )
@@ -114,7 +115,9 @@ impl NcDirect {
             res,
             &format!(
                 "NcDirect.render_frame({:?}, {:?}, {:?})",
-                filename, blitter, scale
+                filename,
+                blitter.into(),
+                scale.into()
             )
         ]
     }
@@ -132,23 +135,27 @@ impl NcDirect {
     pub fn render_image(
         &mut self,
         filename: &str,
-        align: NcAlign,
-        blitter: NcBlitter,
-        scale: NcScale,
+        align: impl Into<NcAlign> + Copy,
+        blitter: impl Into<NcBlitter> + Copy,
+        scale: impl Into<NcScale> + Copy,
     ) -> NcResult<()> {
+        let cs = cstring![filename];
         error![
             unsafe {
                 c_api::ncdirect_render_image(
                     self,
-                    cstring![filename],
-                    align.into(),
-                    blitter.into(),
-                    scale.into(),
+                    cs.as_ptr(),
+                    align.into().into(),
+                    blitter.into().into(),
+                    scale.into().into(),
                 )
             },
             &format!(
                 "NcDirect.render_image({:?}, {:?}, {:?}, {:?})",
-                filename, align, blitter, scale
+                filename,
+                align.into(),
+                blitter.into(),
+                scale.into()
             )
         ]
     }
@@ -159,20 +166,20 @@ impl NcDirect {
     /// Sets the foreground [`NcPaletteIndex`].
     ///
     /// *C style function: [ncdirect_set_fg_palindex()][c_api::ncdirect_set_fg_palindex].*
-    pub fn set_fg_palindex(&mut self, index: NcPaletteIndex) -> NcResult<()> {
+    pub fn set_fg_palindex(&mut self, index: impl Into<NcPaletteIndex> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_set_fg_palindex(self, index as i32) },
-            &format!("NcDirect.set_fg_palindex({})", index)
+            unsafe { c_api::ncdirect_set_fg_palindex(self, index.into() as i32) },
+            &format!("NcDirect.set_fg_palindex({})", index.into())
         ]
     }
 
     /// Sets the background [`NcPaletteIndex`].
     ///
     /// *C style function: [ncdirect_set_bg_palindex()][c_api::ncdirect_set_bg_palindex].*
-    pub fn set_bg_palindex(&mut self, index: NcPaletteIndex) -> NcResult<()> {
+    pub fn set_bg_palindex(&mut self, index: impl Into<NcPaletteIndex> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_set_bg_palindex(self, index as i32) },
-            &format!("NcDirect.set_fg_palindex({})", index)
+            unsafe { c_api::ncdirect_set_bg_palindex(self, index.into() as i32) },
+            &format!("NcDirect.set_fg_palindex({})", index.into())
         ]
     }
 
@@ -197,10 +204,7 @@ impl NcDirect {
     /// Sets the foreground [`NcRgb`].
     ///
     /// *C style function: [ncdirect_set_fg_rgb()][c_api::ncdirect_set_fg_rgb].*
-    pub fn set_fg_rgb<RGB>(&mut self, rgb: RGB) -> NcResult<()>
-    where
-        RGB: Into<NcRgb>,
-    {
+    pub fn set_fg_rgb(&mut self, rgb: impl Into<NcRgb>) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_set_fg_rgb(self, rgb.into().into()) },
             "NcDirect.set_fg_rgb()"
@@ -210,36 +214,13 @@ impl NcDirect {
     /// Sets the background [`NcRgb`].
     ///
     /// *C style function: [ncdirect_set_bg_rgb()][c_api::ncdirect_set_bg_rgb].*
-    pub fn set_bg_rgb<RGB>(&mut self, rgb: RGB) -> NcResult<()>
-    where
-        RGB: Into<NcRgb>,
-    {
+    pub fn set_bg_rgb(&mut self, rgb: impl Into<NcRgb>) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_set_bg_rgb(self, rgb.into().into()) },
             "NcDirect.set_bg_rgb({:?})"
         ]
     }
 
-    /// Sets the foreground individual RGB components.
-    ///
-    /// *C style function: [ncdirect_set_fg_rgb8()][c_api::ncdirect_set_fg_rgb8].*
-    pub fn set_fg_rgb8(&mut self, red: u8, green: u8, blue: u8) -> NcResult<()> {
-        error![
-            c_api::ncdirect_set_fg_rgb8(self, red, green, blue),
-            &format!("NcDirect.set_fg_rgb8({}, {}, {})", red, green, blue)
-        ]
-    }
-
-    /// Sets the background individual RGB components.
-    ///
-    /// *C style function: [ncdirect_set_bg_rgb()][c_api::ncdirect_set_bg_rgb].*
-    pub fn set_bg_rgb8(&mut self, red: u8, green: u8, blue: u8) -> NcResult<()> {
-        error![
-            c_api::ncdirect_set_bg_rgb8(self, red, green, blue),
-            &format!("NcDirect.set_bg_rgb8({}, {}, {})", red, green, blue)
-        ]
-    }
-
     /// Returns the current styling.
     ///
     /// *C style function: [ncdirect_styles()][c_api::ncdirect_styles].*
@@ -250,30 +231,30 @@ impl NcDirect {
     /// Removes the specified styles.
     ///
     /// *C style function: [ncdirect_off_styles()][c_api::ncdirect_off_styles].*
-    pub fn styles_off(&mut self, stylebits: NcStyle) -> NcResult<()> {
+    pub fn styles_off(&mut self, stylebits: impl Into<NcStyle> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_off_styles(self, stylebits.into()) },
-            &format!("NcDirect.styles_off({:0X})", stylebits)
+            unsafe { c_api::ncdirect_off_styles(self, stylebits.into().into()) },
+            &format!("NcDirect.styles_off({:0X})", stylebits.into())
         ]
     }
 
     /// Adds the specified styles.
     ///
     /// *C style function: [ncdirect_on_styles()][c_api::ncdirect_on_styles].*
-    pub fn styles_on(&mut self, stylebits: NcStyle) -> NcResult<()> {
+    pub fn styles_on(&mut self, stylebits: impl Into<NcStyle> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_on_styles(self, stylebits.into()) },
-            &format!("NcDirect.styles_on({:0X})", stylebits)
+            unsafe { c_api::ncdirect_on_styles(self, stylebits.into().into()) },
+            &format!("NcDirect.styles_on({:0X})", stylebits.into())
         ]
     }
 
     /// Sets just the specified styles.
     ///
     /// *C style function: [ncdirect_set_styles()][c_api::ncdirect_set_styles].*
-    pub fn styles_set(&mut self, stylebits: NcStyle) -> NcResult<()> {
+    pub fn styles_set(&mut self, stylebits: impl Into<NcStyle> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_set_styles(self, stylebits.into()) },
-            &format!("NcDirect.styles_set({:0X})", stylebits)
+            unsafe { c_api::ncdirect_set_styles(self, stylebits.into().into()) },
+            &format!("NcDirect.styles_set({:0X})", stylebits.into())
         ]
     }
 
@@ -587,18 +568,8 @@ impl NcDirect {
     /// *C style function: [ncdirect_get()][c_api::ncdirect_get].*
     // CHECK returns 0 on a timeout.
     pub fn get(&mut self, time: Option<NcTime>, input: Option<&mut NcInput>) -> NcResult<char> {
-        let ntime;
-        if let Some(time) = time {
-            ntime = &time as *const _;
-        } else {
-            ntime = null();
-        }
-        let ninput;
-        if let Some(input) = input {
-            ninput = input as *mut _;
-        } else {
-            ninput = null_mut();
-        }
+        let ntime = if let Some(time) = time { &time as *const _ } else { null() };
+        let ninput = if let Some(input) = input { input as *mut _ } else { null_mut() };
 
         let res = unsafe { c_api::ncdirect_get(self, ntime, ninput) };
         core::char::from_u32(res)
@@ -654,10 +625,11 @@ impl NcDirect {
     /// are both marked as using the default color.
     ///
     /// *C style function: [ncdirect_putstr()][c_api::ncdirect_putstr].*
-    pub fn putstr(&mut self, channels: NcChannels, string: &str) -> NcResult<()> {
+    pub fn putstr(&mut self, channels: impl Into<NcChannels> + Copy, string: &str) -> NcResult<()> {
+        let cs = cstring![string];
         error![
-            unsafe { c_api::ncdirect_putstr(self, channels.into(), cstring![string]) },
-            &format!("NcDirect.putstr({:0X}, {:?})", channels, string)
+            unsafe { c_api::ncdirect_putstr(self, channels.into().into(), cs.as_ptr()) },
+            &format!("NcDirect.putstr({:0X}, {:?})", channels.into(), string)
         ]
     }
 
@@ -666,15 +638,16 @@ impl NcDirect {
     /// Initializes Readline the first time it's called.
     ///
     /// For input to be echoed to the terminal, it is necessary that the flag
-    /// [`NcDirectFlags::INHIBIT_CBREAK`][0] be provided to the constructor.
+    /// [`NcDirectFlag::INHIBIT_CBREAK`][0] be provided to the constructor.
     ///
-    /// [0]: NcDirectFlags#associatedconstant.INHIBIT_CBREAK
+    /// [0]: NcDirectFlag#associatedconstant.INHIBIT_CBREAK
     ///
     /// *C style function: [ncdirect_readline()][c_api::ncdirect_readline].*
     //
-    // FIXME: memory leak still reported by valgrind
+    // CHECK if memory leak still reported by valgrind
     pub fn readline(&mut self, prompt: &str) -> NcResult<String> {
-        let res = unsafe { c_api::ncdirect_readline(self, cstring![prompt]) };
+        let cs = cstring![prompt];
+        let res = unsafe { c_api::ncdirect_readline(self, cs.as_ptr()) };
         if !res.is_null() {
             return Ok(rstring_free![res]);
         } else {
@@ -698,10 +671,10 @@ impl NcDirect {
     // TODO: CHECK, specially wchars.
     pub fn r#box(
         &mut self,
-        ul: NcChannels,
-        ur: NcChannels,
-        ll: NcChannels,
-        lr: NcChannels,
+        ul: impl Into<NcChannels> + Copy,
+        ur: impl Into<NcChannels> + Copy,
+        ll: impl Into<NcChannels> + Copy,
+        lr: impl Into<NcChannels> + Copy,
         wchars: &[char; 6],
         len_y: u32,
         len_x: u32,
@@ -710,11 +683,28 @@ impl NcDirect {
         error![
             unsafe {
                 let wchars = core::mem::transmute(wchars);
-                c_api::ncdirect_box(self, ul.0, ur.0, ll.0, lr.0, wchars, len_y, len_x, ctlword)
+                c_api::ncdirect_box(
+                    self,
+                    ul.into().0,
+                    ur.into().0,
+                    ll.into().0,
+                    lr.into().0,
+                    wchars,
+                    len_y,
+                    len_x,
+                    ctlword,
+                )
             },
             &format!(
                 "NcDirect.box({:0X}, {:0X}, {:0X}, {:0X}, {:?}, {}, {}, {})",
-                ul, ur, ll, lr, wchars, len_y, len_x, ctlword
+                ul.into(),
+                ur.into(),
+                ll.into(),
+                lr.into(),
+                wchars,
+                len_y,
+                len_x,
+                ctlword
             )
         ]
     }
@@ -724,16 +714,25 @@ impl NcDirect {
     /// *C style function: [ncdirect_double_box()][c_api::ncdirect_double_box].*
     pub fn double_box(
         &mut self,
-        ul: NcChannels,
-        ur: NcChannels,
-        ll: NcChannels,
-        lr: NcChannels,
+        ul: impl Into<NcChannels>,
+        ur: impl Into<NcChannels>,
+        ll: impl Into<NcChannels>,
+        lr: impl Into<NcChannels>,
         len_y: u32,
         len_x: u32,
         ctlword: u32,
     ) -> NcResult<()> {
         error![unsafe {
-            c_api::ncdirect_double_box(self, ul.0, ur.0, ll.0, lr.0, len_y, len_x, ctlword)
+            c_api::ncdirect_double_box(
+                self,
+                ul.into().0,
+                ur.into().0,
+                ll.into().0,
+                lr.into().0,
+                len_y,
+                len_x,
+                ctlword,
+            )
         }]
     }
 
@@ -742,16 +741,25 @@ impl NcDirect {
     /// *C style function: [ncdirect_rounded_box()][c_api::ncdirect_rounded_box].*
     pub fn rounded_box(
         &mut self,
-        ul: NcChannels,
-        ur: NcChannels,
-        ll: NcChannels,
-        lr: NcChannels,
+        ul: impl Into<NcChannels>,
+        ur: impl Into<NcChannels>,
+        ll: impl Into<NcChannels>,
+        lr: impl Into<NcChannels>,
         len_y: u32,
         len_x: u32,
         ctlword: u32,
     ) -> NcResult<()> {
         error![unsafe {
-            c_api::ncdirect_rounded_box(self, ul.0, ur.0, ll.0, lr.0, len_y, len_x, ctlword)
+            c_api::ncdirect_rounded_box(
+                self,
+                ul.into().0,
+                ur.into().0,
+                ll.into().0,
+                lr.into().0,
+                len_y,
+                len_x,
+                ctlword,
+            )
         }]
     }
 
@@ -771,10 +779,16 @@ impl NcDirect {
         &mut self,
         egc: &str,
         len: u32,
-        h1: NcChannels,
-        h2: NcChannels,
+        h1: impl Into<NcChannels>,
+        h2: impl Into<NcChannels>,
     ) -> NcResult<()> {
-        error![c_api::ncdirect_hline_interp(self, egc, len, h1.0, h2.0)]
+        error![c_api::ncdirect_hline_interp(
+            self,
+            egc,
+            len,
+            h1.into().0,
+            h2.into().0
+        )]
     }
 
     /// Draws horizontal lines using the specified [NcChannels]s, interpolating
@@ -793,9 +807,15 @@ impl NcDirect {
         &mut self,
         egc: &str,
         len: u32,
-        h1: NcChannels,
-        h2: NcChannels,
+        h1: impl Into<NcChannels>,
+        h2: impl Into<NcChannels>,
     ) -> NcResult<()> {
-        error![c_api::ncdirect_vline_interp(self, egc, len, h1.0, h2.0)]
+        error![c_api::ncdirect_vline_interp(
+            self,
+            egc,
+            len,
+            h1.into().0,
+            h2.into().0
+        )]
     }
 }
