@@ -76,12 +76,7 @@ pub fn ncdirect_capabilities(ncd: &NcDirect) -> NcCapabilities {
 /// *Method: NcDirect.[get_blocking()][NcDirect#method.get_blocking].*
 #[inline]
 pub fn ncdirect_get_blocking(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcResult_i32 {
-    let input_ptr;
-    if let Some(i) = input {
-        input_ptr = i as *mut _;
-    } else {
-        input_ptr = null_mut();
-    }
+    let input_ptr = if let Some(i) = input { i as *mut _ } else { null_mut() };
     unsafe { c_api::ncdirect_get(ncd, null(), input_ptr) as NcResult_i32 }
 }
 
@@ -96,12 +91,7 @@ pub fn ncdirect_get_blocking(ncd: &mut NcDirect, input: Option<&mut NcInput>) ->
 /// *Method: NcDirect.[get_nblock()][NcDirect#method.get_nblock].*
 #[inline]
 pub fn ncdirect_get_nblock(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcResult_i32 {
-    let input_ptr;
-    if let Some(i) = input {
-        input_ptr = i as *mut _;
-    } else {
-        input_ptr = null_mut();
-    }
+    let input_ptr = if let Some(i) = input { i as *mut _ } else { null_mut() };
     unsafe {
         let ts = NcTime::new(0, 0);
         c_api::ncdirect_get(ncd, &ts, input_ptr) as NcResult_i32
@@ -110,7 +100,7 @@ pub fn ncdirect_get_nblock(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> N
 
 /// Sets the foreground component components.
 ///
-/// *Method: NcDirect.[set_fg_rgb8()][NcDirect#method.set_fg_rgb8].*
+/// *Method: NcDirect.[set_fg_rgb()][NcDirect#method.set_fg_rgb].*
 #[inline]
 pub fn ncdirect_set_fg_rgb8(ncd: &mut NcDirect, red: u8, green: u8, blue: u8) -> NcResult_i32 {
     let rgb = (red as NcRgb_u32) << 16 | (green as NcRgb_u32) << 8 | blue as NcRgb_u32;
@@ -119,7 +109,7 @@ pub fn ncdirect_set_fg_rgb8(ncd: &mut NcDirect, red: u8, green: u8, blue: u8) ->
 
 /// Sets the background component components.
 ///
-/// *Method: NcDirect.[set_bg_rgb8()][NcDirect#method.set_bg_rgb8].*
+/// *Method: NcDirect.[set_bg_rgb()][NcDirect#method.set_bg_rgb].*
 #[inline]
 pub fn ncdirect_set_bg_rgb8(ncd: &mut NcDirect, red: u8, green: u8, blue: u8) -> NcResult_i32 {
     let rgb = (red as NcRgb_u32) << 16 | (green as NcRgb_u32) << 8 | blue as NcRgb_u32;
@@ -143,15 +133,17 @@ pub fn ncdirect_hline_interp(
     ncd: &mut NcDirect,
     egc: &str,
     len: u32,
-    h1: NcChannels_u64,
-    h2: NcChannels_u64,
+    h1: impl Into<NcChannels_u64>,
+    h2: impl Into<NcChannels_u64>,
 ) -> NcResult_i32 {
-    #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
-    let egc_ptr = cstring![egc] as *const i8;
-    #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
-    let egc_ptr = cstring![egc];
+    let cs = cstring![egc];
 
-    unsafe { crate::c_api::ffi::ncdirect_hline_interp(ncd, egc_ptr, len, h1, h2) }
+    #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
+    let egc_ptr = cs.as_ptr() as *const i8;
+    #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
+    let egc_ptr = cs.as_ptr();
+
+    unsafe { crate::c_api::ffi::ncdirect_hline_interp(ncd, egc_ptr, len, h1.into(), h2.into()) }
 }
 
 /// Draws horizontal lines using the specified [`NcChannels_u64`]s, interpolating
@@ -170,13 +162,15 @@ pub fn ncdirect_vline_interp(
     ncd: &mut NcDirect,
     egc: &str,
     len: u32,
-    h1: NcChannels_u64,
-    h2: NcChannels_u64,
+    h1: impl Into<NcChannels_u64>,
+    h2: impl Into<NcChannels_u64>,
 ) -> NcResult_i32 {
-    #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
-    let egc_ptr = cstring![egc] as *const i8;
-    #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
-    let egc_ptr = cstring![egc];
+    let cs = cstring![egc];
 
-    unsafe { crate::c_api::ffi::ncdirect_vline_interp(ncd, egc_ptr, len, h1, h2) }
+    #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
+    let egc_ptr = cs.as_ptr() as *const i8;
+    #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
+    let egc_ptr = cs.as_ptr();
+
+    unsafe { crate::c_api::ffi::ncdirect_vline_interp(ncd, egc_ptr, len, h1.into(), h2.into()) }
 }
