@@ -16,7 +16,7 @@
 //! constructors, and error handling with the `NcResult` enum:
 //!
 //! ### Example
-#![doc = concat!["```ignore\n", include_str!("../examples/hello-world-rust.rs"), "\n```" ]]
+#![doc = concat!["```\n", include_str!("../examples/hello-world-rust.rs"), "\n```" ]]
 //!
 //! ### Notes on the Rust API
 //!
@@ -58,7 +58,7 @@
 //! or in case of receiving a pointer, by comparing it to `null_mut()`.
 //!
 //! ### Example
-#![doc = concat!["```ignore\n", include_str!("../examples/hello-world-c.rs"), "\n```" ]]
+#![doc = concat!["```\n", include_str!("../examples/hello-world-c.rs"), "\n```" ]]
 //!
 //! ### The `notcurses` C API docs
 //!
@@ -117,7 +117,7 @@ pub use blitter::NcBlitter;
 pub use capabilities::NcCapabilities;
 pub use cell::NcCell;
 pub use channel::{NcChannel, NcChannels};
-pub use direct::{NcDirect, NcDirectFlags};
+pub use direct::{NcDirect, NcDirectFlag};
 pub use error::{NcError, NcResult};
 pub use fade::{NcFadeCb, NcFadeCtx};
 pub use fd::{NcFdPlane, NcFdPlaneOptions, NcSubproc, NcSubprocOptions};
@@ -125,10 +125,10 @@ pub use file::NcFile;
 pub use input::{NcInput, NcInputType, NcMiceEvents, NcReceived};
 pub use key::{NcKey, NcKeyMod};
 pub use log_level::NcLogLevel;
-pub use notcurses::{Nc, NcFlags, NcOptions};
+pub use notcurses::{Nc, NcFlag, NcOptions};
 pub use palette::{NcPalette, NcPaletteIndex};
 pub use pixel::{NcPixel, NcPixelGeometry, NcPixelImpl};
-pub use plane::{NcPlane, NcPlaneOptions, NcPlaneOptionsBuilder};
+pub use plane::{NcPlane, NcPlaneFlag, NcPlaneOptions, NcPlaneOptionsBuilder};
 pub use r#box::NcBoxMask;
 pub use resizecb::NcResizeCb;
 pub use rgb::{NcRgb, NcRgba};
@@ -137,7 +137,9 @@ pub use stats::NcStats;
 pub use string::NcString;
 pub use style::NcStyle;
 pub use time::NcTime;
-pub use visual::{NcVisual, NcVisualGeometry, NcVisualOptions, NcVisualOptionsBuilder};
+pub use visual::{
+    NcVisual, NcVisualFlag, NcVisualGeometry, NcVisualOptions, NcVisualOptionsBuilder,
+};
 
 pub mod c_api {
     //! The `C API`, including structs, constants, functions and type aliases.
