@@ -5,8 +5,8 @@ use core::ptr::{null, null_mut};
 use crate::{
     c_api::{self, notcurses_init},
     cstring, error, error_ref_mut, rstring, rstring_free, Nc, NcAlign, NcBlitter, NcCapabilities,
-    NcChannels, NcError, NcFile, NcFlags, NcInput, NcLogLevel, NcMiceEvents, NcOptions,
-    NcPixelImpl, NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle, NcTime, NcVisual,
+    NcChannels, NcError, NcFile, NcFlag, NcInput, NcLogLevel, NcMiceEvents, NcOptions, NcPixelImpl,
+    NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle, NcTime, NcVisual,
     NcVisualGeometry, NcVisualOptions,
 };
 
@@ -14,17 +14,17 @@ use crate::{
 impl NcOptions {
     /// New `NcOptions`.
     pub fn new() -> Self {
-        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, NcFlags::None)
+        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, NcFlag::None)
     }
 
     /// New `NcOptions`, with margins.
     pub fn with_margins(top: u32, right: u32, bottom: u32, left: u32) -> Self {
-        Self::with_all_options(NcLogLevel::Silent, top, right, bottom, left, NcFlags::None)
+        Self::with_all_options(NcLogLevel::Silent, top, right, bottom, left, NcFlag::None)
     }
 
     /// New `NcOptions`, with flags.
-    pub fn with_flags(flags: NcFlags) -> Self {
-        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, flags)
+    pub fn with_flags(flags: impl Into<NcFlag>) -> Self {
+        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, flags.into())
     }
 
     /// New `NcOptions`, with all the options.
@@ -51,21 +51,21 @@ impl NcOptions {
     ///   can be added without reshaping the struct.
     ///   Undefined bits must be set to 0.
     pub fn with_all_options(
-        loglevel: NcLogLevel,
+        loglevel: impl Into<NcLogLevel>,
         margin_t: u32,
         margin_r: u32,
         margin_b: u32,
         margin_l: u32,
-        flags: NcFlags,
+        flags: impl Into<NcFlag>,
     ) -> Self {
         Self {
             termtype: null(),
-            loglevel: loglevel.into(),
+            loglevel: loglevel.into().into(),
             margin_t,
             margin_r,
             margin_b,
             margin_l,
-            flags: flags.into(),
+            flags: flags.into().into(),
         }
     }
 }
@@ -81,23 +81,23 @@ impl Nc {
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn new<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlags::SuppressBanners)
+        Self::with_flags(NcFlag::SuppressBanners)
     }
 
     /// New notcurses context in CLI mode.
     ///
     /// It has the following flags:
-    /// - [`NcFlags::SuppressBanners`][NcFlags#associatedconstant.SuppressBanners]
-    /// - [`NcFlags::NoAlternateScreen`][NcFlags#associatedconstant.NoAlternateScreen]
-    /// - [`NcFlags::NoClearBitmaps`][NcFlags#associatedconstant.NoClearBitmaps]
-    /// - [`NcFlags::PreserveCursor`][NcFlags#associatedconstant.PreserveCursor]
+    /// - [`NcFlag::SuppressBanners`][NcFlag#associatedconstant.SuppressBanners]
+    /// - [`NcFlag::NoAlternateScreen`][NcFlag#associatedconstant.NoAlternateScreen]
+    /// - [`NcFlag::NoClearBitmaps`][NcFlag#associatedconstant.NoClearBitmaps]
+    /// - [`NcFlag::PreserveCursor`][NcFlag#associatedconstant.PreserveCursor]
     ///
     /// # Safety
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn new_cli<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlags::CliMode)
+        Self::with_flags(NcFlag::CliMode)
     }
 
     /// New notcurses context, with banners.
@@ -109,7 +109,7 @@ impl Nc {
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn with_banners<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlags::None)
+        Self::with_flags(NcFlag::None)
     }
 
     /// New notcurses context, without an alternate screen (nor banners).
@@ -117,17 +117,17 @@ impl Nc {
     #[deprecated]
     #[doc(hidden)]
     pub unsafe fn without_altscreen<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlags::NoAlternateScreen | NcFlags::SuppressBanners)
+        Self::with_flags(NcFlag::NoAlternateScreen | NcFlag::SuppressBanners)
     }
 
-    /// New notcurses context, expects [`NcFlags`].
+    /// New notcurses context, expects [`NcFlag`].
     ///
     /// # Safety
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
-    pub unsafe fn with_flags<'a>(flags: NcFlags) -> NcResult<&'a mut Nc> {
-        Self::with_options(NcOptions::with_flags(flags))
+    pub unsafe fn with_flags<'a>(flags: impl Into<NcFlag>) -> NcResult<&'a mut Nc> {
+        Self::with_options(NcOptions::with_flags(flags.into()))
     }
 
     /// New notcurses context, expects [NcOptions].
@@ -147,8 +147,18 @@ impl Nc {
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
-    pub unsafe fn with_debug<'a>(loglevel: NcLogLevel, flags: NcFlags) -> NcResult<&'a mut Nc> {
-        Self::with_options(NcOptions::with_all_options(loglevel, 0, 0, 0, 0, flags))
+    pub unsafe fn with_debug<'a>(
+        loglevel: impl Into<NcLogLevel>,
+        flags: impl Into<NcFlag>,
+    ) -> NcResult<&'a mut Nc> {
+        Self::with_options(NcOptions::with_all_options(
+            loglevel.into(),
+            0,
+            0,
+            0,
+            0,
+            flags.into(),
+        ))
     }
 
     /// Destroys the notcurses context.
@@ -171,11 +181,11 @@ impl Nc {
     /// [`NcAlign::Unaligned`].
     ///
     /// *C style function: [notcurses_align()][c_api::notcurses_align].*
-    pub fn align(availcols: u32, align: NcAlign, cols: u32) -> NcResult<u32> {
-        let res = c_api::notcurses_align(availcols, align, cols);
+    pub fn align(availcols: u32, align: impl Into<NcAlign> + Copy, cols: u32) -> NcResult<u32> {
+        let res = c_api::notcurses_align(availcols, align.into(), cols);
         error![
             res,
-            &format!("NcPlane.valign({:?}, {})", align, cols),
+            &format!("NcPlane.align({:?}, {})", align.into(), cols),
             res as u32
         ]
     }
@@ -444,19 +454,8 @@ impl Nc {
         time: Option<NcTime>,
         input: Option<&mut NcInput>,
     ) -> NcResult<NcReceived> {
-        let ntime;
-        if let Some(time) = time {
-            ntime = &time as *const _;
-        } else {
-            ntime = null();
-        }
-
-        let ninput;
-        if let Some(input) = input {
-            ninput = input as *mut _;
-        } else {
-            ninput = null_mut();
-        }
+        let ntime = if let Some(time) = time { &time as *const _ } else { null() };
+        let ninput = if let Some(input) = input { input as *mut _ } else { null_mut() };
 
         let res = unsafe { c_api::notcurses_get(self, ntime, ninput) };
         if res == c_api::NCRESULT_ERR as u32 {
@@ -509,12 +508,7 @@ impl Nc {
         ni: &mut Vec<NcInput>,
         vcount: u32,
     ) -> NcResult<u32> {
-        let ntime;
-        if let Some(time) = time {
-            ntime = &time as *const _;
-        } else {
-            ntime = null();
-        }
+        let ntime = if let Some(time) = time { &time as *const _ } else { null() };
         let nivec = ni.as_mut_ptr() as *mut NcInput;
 
         let res = unsafe { c_api::notcurses_getvec(self, ntime, nivec, vcount as i32) };
@@ -539,8 +533,9 @@ impl Nc {
     /// *C style function: [notcurses_lex_blitter()][c_api::notcurses_lex_blitter].*
     pub fn lex_blitter(blitter_str: &str) -> NcResult<NcBlitter> {
         let mut blitter = 0;
+        let cs = cstring![blitter_str];
         error![
-            unsafe { c_api::notcurses_lex_blitter(cstring![blitter_str], &mut blitter) },
+            unsafe { c_api::notcurses_lex_blitter(cs.as_ptr(), &mut blitter) },
             "Invalid blitter name",
             blitter.into()
         ]
@@ -553,7 +548,8 @@ impl Nc {
     ///
     /// *C style function: [notcurses_lex_margins()][c_api::notcurses_lex_margins].*
     pub fn lex_margins(margins_str: &str, options: &mut NcOptions) -> NcResult<()> {
-        error![unsafe { c_api::notcurses_lex_margins(cstring![margins_str], options) }]
+        let cs = cstring![margins_str];
+        error![unsafe { c_api::notcurses_lex_margins(cs.as_ptr(), options) }]
     }
 
     /// Returns an [`NcScale`] from a string representation.
@@ -561,8 +557,9 @@ impl Nc {
     /// *C style function: [notcurses_lex_scalemode()][c_api::notcurses_lex_scalemode].*
     pub fn lex_scalemode(scale_str: &str) -> NcResult<NcScale> {
         let mut scale = 0;
+        let cs = cstring![scale_str];
         error![
-            unsafe { c_api::notcurses_lex_scalemode(cstring![scale_str], &mut scale) },
+            unsafe { c_api::notcurses_lex_scalemode(cs.as_ptr(), &mut scale) },
             "",
             scale.into()
         ]
@@ -776,23 +773,23 @@ impl Nc {
     /// Gets the name of an [`NcBlitter`] blitter.
     ///
     /// *C style function: [notcurses_str_blitter()][c_api::notcurses_str_blitter].*
-    pub fn str_blitter(blitter: NcBlitter) -> String {
-        rstring![c_api::notcurses_str_blitter(blitter.into())].to_string()
+    pub fn str_blitter(blitter: impl Into<NcBlitter>) -> String {
+        rstring![c_api::notcurses_str_blitter(blitter.into().into())].to_string()
     }
 
     /// Gets the name of an [`NcScale`] scaling mode.
     ///
     /// *C style function: [notcurses_str_scalemode()][c_api::notcurses_str_scalemode].*
-    pub fn str_scalemode(scale: NcScale) -> String {
-        rstring![c_api::notcurses_str_scalemode(scale.into())].to_string()
+    pub fn str_scalemode(scale: impl Into<NcScale>) -> String {
+        rstring![c_api::notcurses_str_scalemode(scale.into().into())].to_string()
     }
 
     /// Gets the lowercase name (or names) of the styles included in an [`NcStyle`].
     ///
     /// *(No equivalent C style function)*
-    pub fn str_styles(style: NcStyle) -> String {
+    pub fn str_styles(style: impl Into<NcStyle>) -> String {
         let mut string = String::new();
-        for s in style.to_vec() {
+        for s in style.into().to_vec() {
             string.push_str(match s {
                 NcStyle::Italic => "italic",
                 NcStyle::Underline => "underline",
@@ -888,19 +885,9 @@ impl Nc {
     ) -> NcResult<NcVisualGeometry> {
         let mut vg = c_api::NcVGeom::new();
 
-        let v_ptr: *const NcVisual;
-        if let Some(v) = visual {
-            v_ptr = v;
-        } else {
-            v_ptr = null();
-        }
-        let vo_ptr: *const NcVisualOptions;
-        if let Some(o) = vopts {
-            vo_ptr = o;
-        } else {
-            let vo = NcVisualOptions::default();
-            vo_ptr = &vo;
-        }
+        let v_ptr: *const NcVisual = if let Some(v) = visual { v } else { null() };
+        let vo_ptr: *const NcVisualOptions =
+            if let Some(o) = vopts { o } else { &NcVisualOptions::default() };
 
         let res = unsafe { crate::c_api::ncvisual_geom(self, v_ptr, vo_ptr, &mut vg) };
         if res <= c_api::NCRESULT_ERR {
