@@ -3,8 +3,8 @@
 use core::ptr::{null, null_mut};
 
 use crate::{
-    c_api::{self, NcResult_i32, NCRESULT_ERR},
-    Nc, NcAlign, NcError, NcInput, NcPlane, NcResult, NcTime,
+    c_api::{self, NcAlign_u32, NcResult_i32, NCRESULT_ERR},
+    Nc, NcError, NcInput, NcPlane, NcResult, NcTime,
 };
 
 /// Returns the offset into `avail_u` at which `u` ought be output given
@@ -15,14 +15,14 @@ use crate::{
 ///
 /// *Method: Nc.[align()][Nc#method.align].*
 #[inline]
-pub fn notcurses_align(avail_u: u32, align: NcAlign, u: u32) -> NcResult_i32 {
-    if align == NcAlign::Left || align == NcAlign::Top {
+pub fn notcurses_align(avail_u: u32, align: impl Into<NcAlign_u32> + Copy, u: u32) -> NcResult_i32 {
+    if align.into() == c_api::NCALIGN_LEFT || align.into() == c_api::NCALIGN_TOP {
         return 0;
     }
-    if align == NcAlign::Center {
+    if align.into() == c_api::NCALIGN_CENTER {
         return ((avail_u - u) / 2) as NcResult_i32;
     }
-    if align == NcAlign::Right || align == NcAlign::Bottom {
+    if align.into() == c_api::NCALIGN_RIGHT || align.into() == c_api::NCALIGN_BOTTOM {
         return (avail_u - u) as NcResult_i32;
     }
     -NcResult_i32::MAX
@@ -116,12 +116,7 @@ pub fn notcurses_cansextant(nc: &Nc) -> bool {
 /// *Method: Nc.[get_blocking()][Nc#method.get_blocking].*
 #[inline]
 pub fn notcurses_get_blocking(nc: &mut Nc, input: Option<&mut NcInput>) -> NcResult_i32 {
-    let input_ptr;
-    if let Some(i) = input {
-        input_ptr = i as *mut _;
-    } else {
-        input_ptr = null_mut();
-    }
+    let input_ptr = if let Some(i) = input { i as *mut _ } else { null_mut() };
     unsafe { c_api::notcurses_get(nc, null(), input_ptr) as NcResult_i32 }
 }
 
@@ -136,12 +131,7 @@ pub fn notcurses_get_blocking(nc: &mut Nc, input: Option<&mut NcInput>) -> NcRes
 /// *Method: Nc.[get_nblock()][Nc#method.get_nblock].*
 #[inline]
 pub fn notcurses_get_nblock(nc: &mut Nc, input: Option<&mut NcInput>) -> NcResult_i32 {
-    let input_ptr;
-    if let Some(i) = input {
-        input_ptr = i as *mut _;
-    } else {
-        input_ptr = null_mut();
-    }
+    let input_ptr = if let Some(i) = input { i as *mut _ } else { null_mut() };
     unsafe {
         let ts = NcTime::new(0, 0);
         c_api::notcurses_get(nc, &ts, input_ptr) as NcResult_i32
