@@ -105,7 +105,7 @@ impl NcPlane {
     /// *C style function: [ncplane_fg_alpha()][c_api::ncplane_fg_alpha].*
     #[inline]
     pub fn fg_alpha(&self) -> NcAlpha {
-        c_api::ncchannels_fg_alpha(c_api::ncplane_channels(self))
+        c_api::ncchannels_fg_alpha(c_api::ncplane_channels(self)).into()
     }
 
     /// Gets the background [`NcAlpha`] for this `NcPlane`, shifted to LSBs.
@@ -113,26 +113,26 @@ impl NcPlane {
     /// *C style function: [ncplane_bg_alpha()][c_api::ncplane_bg_alpha].*
     #[inline]
     pub fn bg_alpha(&self) -> NcAlpha {
-        c_api::ncchannels_bg_alpha(c_api::ncplane_channels(self))
+        c_api::ncchannels_bg_alpha(c_api::ncplane_channels(self)).into()
     }
 
     /// Sets the foreground [`NcAlpha`] from this `NcPlane`.
     ///
     /// *C style function: [ncplane_set_fg_alpha()][c_api::ncplane_set_fg_alpha].*
-    pub fn set_fg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
+    pub fn set_fg_alpha(&mut self, alpha: impl Into<NcAlpha> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncplane_set_fg_alpha(self, alpha as i32) },
-            &format!("NcPlane.set_fg_alpha({})", alpha)
+            unsafe { c_api::ncplane_set_fg_alpha(self, alpha.into() as i32) },
+            &format!("NcPlane.set_fg_alpha({})", alpha.into())
         ]
     }
 
     /// Sets the background [`NcAlpha`] for this `NcPlane`.
     ///
     /// *C style function: [ncplane_set_bg_alpha()][c_api::ncplane_set_bg_alpha].*
-    pub fn set_bg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
+    pub fn set_bg_alpha(&mut self, alpha: impl Into<NcAlpha> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncplane_set_bg_alpha(self, alpha as i32) },
-            &format!("NcPlane.set_bg_alpha({})", alpha)
+            unsafe { c_api::ncplane_set_bg_alpha(self, alpha.into() as i32) },
+            &format!("NcPlane.set_bg_alpha({})", alpha.into())
         ]
     }
 }
@@ -150,8 +150,8 @@ impl NcPlane {
     /// Sets the current [`NcChannels`] for this `NcPlane`.
     ///
     /// *C style function: [ncplane_set_channels()][c_api::ncplane_set_channels].*
-    pub fn set_channels(&mut self, channels: NcChannels) {
-        c_api::ncplane_set_channels(self, channels.0);
+    pub fn set_channels(&mut self, channels: impl Into<NcChannels>) {
+        c_api::ncplane_set_channels(self, channels.into().0);
     }
 
     /// Gets the foreground [`NcChannel`] from an [`NcPlane`].
@@ -174,16 +174,16 @@ impl NcPlane {
     /// Returns the updated [`NcChannels`].
     ///
     /// *C style function: [ncplane_set_fchannel()][c_api::ncplane_set_fchannel].*
-    pub fn set_fchannel(&mut self, channel: NcChannel) -> NcChannels {
-        c_api::ncplane_set_fchannel(self, channel.0).into()
+    pub fn set_fchannel(&mut self, channel: impl Into<NcChannel>) -> NcChannels {
+        c_api::ncplane_set_fchannel(self, channel.into().0).into()
     }
 
     /// Sets the current background [`NcChannel`] for this `NcPlane`.
     /// Returns the updated [`NcChannels`].
     ///
     /// *C style function: [ncplane_set_bchannel()][c_api::ncplane_set_bchannel].*
-    pub fn set_bchannel(&mut self, channel: NcChannel) -> NcChannels {
-        c_api::ncplane_set_bchannel(self, channel.0).into()
+    pub fn set_bchannel(&mut self, channel: impl Into<NcChannel>) -> NcChannels {
+        c_api::ncplane_set_bchannel(self, channel.into().0).into()
     }
 
     /// Sets the given [`NcChannels`]s throughout the specified region,
@@ -206,29 +206,36 @@ impl NcPlane {
         x: Option<u32>,
         len_y: Option<u32>,
         len_x: Option<u32>,
-        ul: NcChannels,
-        ur: NcChannels,
-        ll: NcChannels,
-        lr: NcChannels,
+        ul: impl Into<NcChannels> + Copy,
+        ur: impl Into<NcChannels> + Copy,
+        ll: impl Into<NcChannels> + Copy,
+        lr: impl Into<NcChannels> + Copy,
     ) -> NcResult<u32> {
         let res = unsafe {
             c_api::ncplane_stain(
                 self,
-                y.unwrap_or(u32::MAX) as i32,
-                x.unwrap_or(u32::MAX) as i32,
+                y.unwrap_or(u32::MAX) as i32, // -1_i32
+                x.unwrap_or(u32::MAX) as i32, // "
                 len_y.unwrap_or(0),
                 len_x.unwrap_or(0),
-                ul.0,
-                ur.0,
-                ll.0,
-                lr.0,
+                ul.into().0,
+                ur.into().0,
+                ll.into().0,
+                lr.into().0,
             )
         };
         error![
             res,
             &format!(
                 "NcPlane.stain({:?}, {:?}, {:?}, {:?}, {:0X}, {:0X}, {:0X}, {:0X})",
-                y, x, len_y, len_x, ul, ur, ll, lr
+                y,
+                x,
+                len_y,
+                len_x,
+                ul.into(),
+                ur.into(),
+                ll.into(),
+                lr.into()
             ),
             res as u32
         ]
@@ -238,60 +245,6 @@ impl NcPlane {
 // -----------------------------------------------------------------------------
 /// ## NcPlane methods: `NcRgb`, components & default color
 impl NcPlane {
-    /// Gets the foreground RGB components from this `NcPlane`.
-    ///
-    /// *C style function: [ncplane_fg_rgb8()][c_api::ncplane_fg_rgb8].*
-    #[inline]
-    pub fn fg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        let _ = c_api::ncchannels_fg_rgb8(c_api::ncplane_channels(self), &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
-    /// Gets the background RGB components from this `NcPlane`.
-    ///
-    /// *C style function: [ncplane_bg_rgb8()][c_api::ncplane_bg_rgb8].*
-    #[inline]
-    pub fn bg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        let _ = c_api::ncchannels_bg_rgb8(c_api::ncplane_channels(self), &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
-    /// Sets the foreground RGB components for this `NcPlane`.
-    ///
-    /// If the terminal does not support directly-specified 3x8b cells
-    /// (24-bit "TrueColor", indicated by the "RGB" terminfo capability),
-    /// the provided values will be interpreted in some lossy fashion.
-    ///
-    /// "HP-like" terminals require setting foreground and background at the same
-    /// time using "color pairs"; notcurses will manage color pairs transparently.
-    ///
-    /// *C style function: [ncplane_set_fg_rgb8()][c_api::ncplane_set_fg_rgb8].*
-    pub fn set_fg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
-        unsafe {
-            // Can't fail because of type enforcing.
-            let _ = c_api::ncplane_set_fg_rgb8(self, red as u32, green as u32, blue as u32);
-        }
-    }
-
-    /// Sets the background RGB components for this `NcPlane`.
-    ///
-    /// If the terminal does not support directly-specified 3x8b cells
-    /// (24-bit "TrueColor", indicated by the "RGB" terminfo capability),
-    /// the provided values will be interpreted in some lossy fashion.
-    ///
-    /// "HP-like" terminals require setting foreground and background at the same
-    /// time using "color pairs"; notcurses will manage color pairs transparently.
-    ///
-    /// *C style function: [ncplane_set_bg_rgb8()][c_api::ncplane_set_bg_rgb8].*
-    pub fn set_bg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
-        unsafe {
-            // Can't fail because of type enforcing.
-            let _ = c_api::ncplane_set_bg_rgb8(self, red as u32, green as u32, blue as u32);
-        }
-    }
-
     /// Gets the foreground [`NcRgb`] from this `NcPlane`, shifted to LSBs.
     ///
     /// *C style function: [ncplane_fg_rgb()][c_api::ncplane_fg_rgb].*
@@ -312,7 +265,7 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_set_fg_rgb()][c_api::ncplane_set_fg_rgb].*
     #[inline]
-    pub fn set_fg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
+    pub fn set_fg_rgb(&mut self, rgb: impl Into<NcRgb>) {
         unsafe {
             c_api::ncplane_set_fg_rgb(self, rgb.into().into());
         }
@@ -322,7 +275,7 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_set_bg_rgb()][c_api::ncplane_set_bg_rgb].*
     #[inline]
-    pub fn set_bg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
+    pub fn set_bg_rgb(&mut self, rgb: impl Into<NcRgb>) {
         unsafe {
             c_api::ncplane_set_bg_rgb(self, rgb.into().into());
         }
@@ -436,23 +389,27 @@ impl NcPlane {
         x: Option<u32>,
         len_y: Option<u32>,
         len_x: Option<u32>,
-        stylemask: NcStyle,
+        stylemask: impl Into<NcStyle> + Copy,
     ) -> NcResult<u32> {
         let res = unsafe {
             c_api::ncplane_format(
                 self,
-                y.unwrap_or(u32::MAX) as i32,
-                x.unwrap_or(u32::MAX) as i32,
+                y.unwrap_or(u32::MAX) as i32, // -1_i32
+                x.unwrap_or(u32::MAX) as i32, // "
                 len_y.unwrap_or(0),
                 len_x.unwrap_or(0),
-                stylemask.into(),
+                stylemask.into().into(),
             )
         };
         error![
             res,
             &format!(
                 "NcPlane.format({:?}, {:?}, {:?}, {:?}, {:0X})",
-                y, x, len_y, len_x, stylemask
+                y,
+                x,
+                len_y,
+                len_x,
+                stylemask.into()
             ),
             res as u32
         ]
@@ -468,27 +425,27 @@ impl NcPlane {
     /// Removes the specified styles from this `NcPlane`'s existing spec.
     ///
     /// *C style function: [ncplane_off_styles()][c_api::ncplane_off_styles].*
-    pub fn off_styles(&mut self, stylemask: NcStyle) {
+    pub fn off_styles(&mut self, stylemask: impl Into<NcStyle>) {
         unsafe {
-            c_api::ncplane_off_styles(self, stylemask.into());
+            c_api::ncplane_off_styles(self, stylemask.into().into());
         }
     }
 
     /// Adds the specified styles to this `NcPlane`'s existing spec.
     ///
     /// *C style function: [ncplane_on_styles()][c_api::ncplane_on_styles].*
-    pub fn on_styles(&mut self, stylemask: NcStyle) {
+    pub fn on_styles(&mut self, stylemask: impl Into<NcStyle>) {
         unsafe {
-            c_api::ncplane_on_styles(self, stylemask.into());
+            c_api::ncplane_on_styles(self, stylemask.into().into());
         }
     }
 
     /// Sets just the specified styles for this `NcPlane`.
     ///
     /// *C style function: [ncplane_set_styles()][c_api::ncplane_set_styles].*
-    pub fn set_styles(&mut self, stylemask: NcStyle) {
+    pub fn set_styles(&mut self, stylemask: impl Into<NcStyle>) {
         unsafe {
-            c_api::ncplane_set_styles(self, stylemask.into());
+            c_api::ncplane_set_styles(self, stylemask.into().into());
         }
     }
 
@@ -498,21 +455,21 @@ impl NcPlane {
     /// and clears the foreground default color bit.
     ///
     /// *C style function: [ncplane_set_fg_palindex()][c_api::ncplane_set_fg_palindex].*
-    pub fn set_fg_palindex(&mut self, palindex: NcPaletteIndex) {
+    pub fn set_fg_palindex(&mut self, palindex: impl Into<NcPaletteIndex>) {
         unsafe {
-            c_api::ncplane_set_fg_palindex(self, palindex as u32);
+            c_api::ncplane_set_fg_palindex(self, palindex.into() as u32);
         }
     }
 
-    /// Sets this `NcPlane`'s background [`NcPaletteIndex`].
+    /// Sets this `NcPlane`'s background [`impl Into<NcPaletteIndex>`].
     ///
     /// Also sets the background palette index bit, sets it background-opaque,
     /// and clears the background default color bit.
     ///
     /// *C style function: [ncplane_set_bg_palindex()][c_api::ncplane_set_bg_palindex].*
-    pub fn set_bg_palindex(&mut self, palindex: NcPaletteIndex) {
+    pub fn set_bg_palindex(&mut self, palindex: impl Into<NcPaletteIndex>) {
         unsafe {
-            c_api::ncplane_set_bg_palindex(self, palindex as u32);
+            c_api::ncplane_set_bg_palindex(self, palindex.into() as u32);
         }
     }
 }
@@ -637,14 +594,20 @@ impl NcPlane {
     //      return nccell_load(n, c, gcluster);
     // - cell-load calls internal.h/pool load:
     //      return pool_load(&n->pool, c, gcluster);
-    pub fn set_base<S: Into<NcStyle> + Copy>(
+    pub fn set_base(
         &mut self,
         egc: &str,
-        stylemask: S,
-        channels: NcChannels,
+        stylemask: impl Into<NcStyle> + Copy,
+        channels: impl Into<NcChannels> + Copy,
     ) -> NcResult<u32> {
+        let cs = cstring![egc];
         let res = unsafe {
-            c_api::ncplane_set_base(self, cstring![egc], stylemask.into().into(), channels.0)
+            c_api::ncplane_set_base(
+                self,
+                cs.as_ptr(),
+                stylemask.into().into(),
+                channels.into().0,
+            )
         };
         error![
             res,
@@ -652,7 +615,7 @@ impl NcPlane {
                 "NcPlane.set_base({:?}, {:0X}, {:0X})",
                 egc,
                 stylemask.into(),
-                channels
+                channels.into()
             ),
             res as u32
         ]
@@ -695,8 +658,8 @@ impl NcPlane {
     ) -> String {
         rstring_free![c_api::ncplane_contents(
             self,
-            beg_y.unwrap_or(u32::MAX) as i32,
-            beg_x.unwrap_or(u32::MAX) as i32,
+            beg_y.unwrap_or(u32::MAX) as i32, // -1_i32
+            beg_x.unwrap_or(u32::MAX) as i32, // "
             len_y.unwrap_or(0),
             len_x.unwrap_or(0)
         )]
@@ -760,8 +723,8 @@ impl NcPlane {
             unsafe {
                 c_api::ncplane_erase_region(
                     self,
-                    beg_y.unwrap_or(u32::MAX) as i32, // unwrap_or(-1)
-                    beg_x.unwrap_or(u32::MAX) as i32, // unwrap_or(-1)
+                    beg_y.unwrap_or(u32::MAX) as i32, // -1_i32
+                    beg_x.unwrap_or(u32::MAX) as i32, // "
                     len_y,
                     len_x,
                 )
@@ -966,9 +929,10 @@ impl NcPlane {
     /// scrolling is enabled.
     ///
     /// *C style function: [ncplane_puttext()][c_api::ncplane_puttext].*
-    pub fn puttext(&mut self, y: u32, align: NcAlign, string: &str) -> NcResult<u32> {
+    pub fn puttext(&mut self, y: u32, align: impl Into<NcAlign>, string: &str) -> NcResult<u32> {
+        let cs = cstring![string];
         let res = unsafe {
-            c_api::ncplane_puttext(self, y as i32, align.into(), cstring![string], null_mut())
+            c_api::ncplane_puttext(self, y as i32, align.into().into(), cs.as_ptr(), null_mut())
         };
         error![res, &format!("NcPlane.puttext({:?})", string), res as u32]
     }
@@ -1050,13 +1014,18 @@ impl NcPlane {
     pub fn putstr_aligned(
         &mut self,
         y: Option<u32>,
-        align: NcAlign,
+        align: impl Into<NcAlign> + Copy,
         string: &str,
     ) -> NcResult<u32> {
-        let res = c_api::ncplane_putstr_aligned(self, y, align, string);
+        let res = c_api::ncplane_putstr_aligned(self, y, align.into(), string);
         error![
             res,
-            &format!("NcPlane.putstr_aligned({:?}, {}, {:?})", y, align, string),
+            &format!(
+                "NcPlane.putstr_aligned({:?}, {}, {:?})",
+                y,
+                align.into(),
+                string
+            ),
             res as u32
         ]
     }
@@ -1098,7 +1067,7 @@ impl NcPlane {
     pub fn putstr_aligned_stained(
         &mut self,
         y: u32,
-        align: NcAlign,
+        align: impl Into<NcAlign> + Copy,
         string: &str,
     ) -> NcResult<u32> {
         let width = string.chars().count() as u32;
@@ -1109,7 +1078,9 @@ impl NcPlane {
             res,
             &format!(
                 "NcPlane.putstr_aligned_stained({}, {}, {:?})",
-                y, align, string
+                y,
+                align.into(),
+                string
             ),
             res as u32
         ]
@@ -1177,24 +1148,28 @@ impl NcPlane {
     pub fn putnstr_aligned(
         &mut self,
         y: u32,
-        align: NcAlign,
+        align: impl Into<NcAlign> + Copy,
         num_bytes: usize,
         string: &str,
     ) -> NcResult<u32> {
+        let cs = cstring![string];
         let res = unsafe {
             c_api::ncplane_putnstr_aligned(
                 self,
                 y as i32,
-                align.into(),
+                align.into().into(),
                 num_bytes,
-                cstring![string],
+                cs.as_ptr(),
             )
         };
         error![
             res,
             &format!(
                 "NcPlane.putnstr_aligned({}, {}, {}, {:?})",
-                y, align, num_bytes, string
+                y,
+                align.into(),
+                num_bytes,
+                string
             ),
             res as u32
         ]
@@ -1511,12 +1486,12 @@ impl NcPlane {
                 c_api::ncplane_mergedown(
                     source,
                     self,
-                    beg_src_y.unwrap_or(u32::MAX) as i32,
-                    beg_src_x.unwrap_or(u32::MAX) as i32,
+                    beg_src_y.unwrap_or(u32::MAX) as i32, // -1_i32
+                    beg_src_x.unwrap_or(u32::MAX) as i32, // "
                     len_y.unwrap_or(0),
                     len_x.unwrap_or(0),
-                    dst_y.unwrap_or(u32::MAX) as i32,
-                    dst_x.unwrap_or(u32::MAX) as i32,
+                    dst_y.unwrap_or(u32::MAX) as i32, // -1_i32
+                    dst_x.unwrap_or(u32::MAX) as i32, // "
                 )
             },
             &format!(
@@ -1807,11 +1782,11 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_halign()][c_api::ncplane_halign].*
     #[inline]
-    pub fn halign(&mut self, align: NcAlign, numcols: u32) -> NcResult<u32> {
-        let res = c_api::ncplane_halign(self, align, numcols);
+    pub fn halign(&mut self, align: impl Into<NcAlign> + Copy, numcols: u32) -> NcResult<u32> {
+        let res = c_api::ncplane_halign(self, align.into(), numcols);
         error![
             res,
-            &format!("NcPlane.halign({:?}, {})", align, numcols),
+            &format!("NcPlane.halign({:?}, {})", align.into(), numcols),
             res as u32
         ]
     }
@@ -1824,11 +1799,11 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_valign()][c_api::ncplane_valign].*
     #[inline]
-    pub fn valign(&mut self, align: NcAlign, numrows: u32) -> NcResult<u32> {
-        let res = c_api::ncplane_valign(self, align, numrows);
+    pub fn valign(&mut self, align: impl Into<NcAlign> + Copy, numrows: u32) -> NcResult<u32> {
+        let res = c_api::ncplane_valign(self, align.into(), numrows);
         error![
             res,
-            &format!("NcPlane.valign({:?}, {})", align, numrows),
+            &format!("NcPlane.valign({:?}, {})", align.into(), numrows),
             res as u32
         ]
     }
@@ -1910,7 +1885,7 @@ impl NcPlane {
     /// *C style function: [ncplane_as_rgba()][c_api::ncplane_as_rgba].*
     pub fn as_rgba(
         &mut self,
-        blitter: NcBlitter,
+        blitter: impl Into<NcBlitter> + Copy,
         beg_y: Option<u32>,
         beg_x: Option<u32>,
         len_y: Option<u32>,
@@ -1923,9 +1898,9 @@ impl NcPlane {
         let res_array = unsafe {
             c_api::ncplane_as_rgba(
                 self,
-                blitter.into(),
-                beg_y.unwrap_or(u32::MAX) as i32,
-                beg_x.unwrap_or(u32::MAX) as i32,
+                blitter.into().into(),
+                beg_y.unwrap_or(u32::MAX) as i32, // -1_i32
+                beg_x.unwrap_or(u32::MAX) as i32, // "
                 len_y.unwrap_or(0),
                 len_x.unwrap_or(0),
                 &mut pxdim_y,
@@ -1937,7 +1912,11 @@ impl NcPlane {
             res_array,
             &format![
                 "NcPlane.rgba({}, {:?}, {:?}, {:?}, {:?})",
-                blitter, beg_y, beg_x, len_y, len_x
+                blitter.into(),
+                beg_y,
+                beg_x,
+                len_y,
+                len_x
             ],
             from_raw_parts_mut(res_array as *mut NcRgba, (pxdim_y * pxdim_x) as usize)
         ]
@@ -2296,7 +2275,7 @@ impl NcPlane {
         vline: &NcCell,
         stop_y: u32,
         stop_x: u32,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![unsafe {
             c_api::ncplane_box(
@@ -2309,7 +2288,7 @@ impl NcPlane {
                 vline,
                 stop_y,
                 stop_x,
-                boxmask.into(),
+                boxmask.into().0,
             )
         }]
     }
@@ -2332,10 +2311,19 @@ impl NcPlane {
         vline: &NcCell,
         len_y: u32,
         len_x: u32,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_box_sized(
-            self, ul, ur, ll, lr, hline, vline, len_y, len_x, boxmask
+            self,
+            ul,
+            ur,
+            ll,
+            lr,
+            hline,
+            vline,
+            len_y,
+            len_x,
+            boxmask.into()
         )]
     }
 
@@ -2345,19 +2333,19 @@ impl NcPlane {
     #[inline]
     pub fn ascii_box(
         &mut self,
-        stylemask: NcStyle,
-        channels: NcChannels,
+        stylemask: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         stop_y: u32,
         stop_x: u32,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_ascii_box(
             self,
-            stylemask.into(),
-            channels.into(),
+            stylemask.into().0,
+            channels.into().0,
             stop_y,
             stop_x,
-            boxmask
+            boxmask.into()
         )]
     }
 
@@ -2367,19 +2355,19 @@ impl NcPlane {
     #[inline]
     pub fn double_box(
         &mut self,
-        stylemask: NcStyle,
-        channels: NcChannels,
+        stylemask: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         stop_y: u32,
         stop_x: u32,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_double_box(
             self,
-            stylemask.into(),
-            channels.into(),
+            stylemask.into().0,
+            channels.into().0,
             stop_y,
             stop_x,
-            boxmask
+            boxmask.into()
         )]
     }
 
@@ -2390,19 +2378,19 @@ impl NcPlane {
     #[inline]
     pub fn double_box_sized(
         &mut self,
-        stylemask: NcStyle,
-        channels: NcChannels,
+        stylemask: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         len_y: u32,
         len_x: u32,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_double_box(
             self,
-            stylemask.into(),
-            channels.into(),
+            stylemask.into().0,
+            channels.into().0,
             len_y,
             len_x,
-            boxmask
+            boxmask.into()
         )]
     }
 
@@ -2418,10 +2406,17 @@ impl NcPlane {
         lr: &NcCell,
         hline: &NcCell,
         vline: &NcCell,
-        boxmask: NcBoxMask,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_perimeter(
-            self, ul, ur, ll, lr, hline, vline, boxmask
+            self,
+            ul,
+            ur,
+            ll,
+            lr,
+            hline,
+            vline,
+            boxmask.into()
         )]
     }
 
@@ -2431,15 +2426,15 @@ impl NcPlane {
     #[inline]
     pub fn perimeter_double(
         &mut self,
-        stylemask: NcStyle,
-        channels: NcChannels,
-        boxmask: NcBoxMask,
+        stylemask: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_perimeter_double(
             self,
-            stylemask.into(),
-            channels.into(),
-            boxmask
+            stylemask.into().0,
+            channels.into().0,
+            boxmask.into()
         )]
     }
 
@@ -2449,15 +2444,15 @@ impl NcPlane {
     #[inline]
     pub fn perimeter_rounded(
         &mut self,
-        stylemask: NcStyle,
-        channels: NcChannels,
-        boxmask: NcBoxMask,
+        stylemask: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
+        boxmask: impl Into<NcBoxMask>,
     ) -> NcResult<()> {
         error![c_api::ncplane_perimeter_rounded(
             self,
-            stylemask.into(),
-            channels.into(),
-            boxmask
+            stylemask.into().0,
+            channels.into().0,
+            boxmask.into()
         )]
     }
 }
@@ -2558,11 +2553,11 @@ impl NcPlane {
         stop_y: Option<u32>,
         stop_x: Option<u32>,
         egc: &str,
-        stylemask: NcStyle,
-        ul: NcChannels,
-        ur: NcChannels,
-        ll: NcChannels,
-        lr: NcChannels,
+        stylemask: impl Into<NcStyle>,
+        ul: impl Into<NcChannels>,
+        ur: impl Into<NcChannels>,
+        ll: impl Into<NcChannels>,
+        lr: impl Into<NcChannels>,
     ) -> NcResult<u32> {
         let res = c_api::ncplane_gradient(
             self,
@@ -2572,10 +2567,10 @@ impl NcPlane {
             stop_x,
             egc,
             stylemask.into(),
-            ul.into(),
-            ur.into(),
-            ll.into(),
-            lr.into(),
+            ul.into().0,
+            ur.into().0,
+            ll.into().0,
+            lr.into().0,
         );
         error![res, "", res as u32]
     }
@@ -2600,22 +2595,22 @@ impl NcPlane {
         x: Option<u32>,
         len_y: Option<u32>,
         len_x: Option<u32>,
-        ul: NcChannel,
-        ur: NcChannel,
-        ll: NcChannel,
-        lr: NcChannel,
+        ul: impl Into<NcChannel>,
+        ur: impl Into<NcChannel>,
+        ll: impl Into<NcChannel>,
+        lr: impl Into<NcChannel>,
     ) -> NcResult<u32> {
         let res = unsafe {
             c_api::ncplane_gradient2x1(
                 self,
-                y.unwrap_or(u32::MAX) as i32,
-                x.unwrap_or(u32::MAX) as i32,
+                y.unwrap_or(u32::MAX) as i32, // -1_i32
+                x.unwrap_or(u32::MAX) as i32, // "
                 len_y.unwrap_or(0),
                 len_x.unwrap_or(0),
-                ul.into(),
-                ur.into(),
-                ll.into(),
-                lr.into(),
+                ul.into().0,
+                ur.into().0,
+                ll.into().0,
+                lr.into().0,
             )
         };
         error![res, "", res as u32]
