@@ -20,33 +20,33 @@ use std::ffi::CString;
 
 use crate::{
     c_api::{
-        self, nccell_release, NcChannel_u32, NcChannels_u64, NcResult_i32, NcRgb_u32, NcStyle_u16,
-        NCRESULT_ERR, NCRESULT_OK,
+        self, nccell_release, NcAlign_u32, NcAlpha_u32, NcBoxMask_u32, NcChannel_u32,
+        NcChannels_u64, NcResult_i32, NcRgb_u32, NcStyle_u16, NCRESULT_ERR, NCRESULT_OK,
     },
-    cstring, NcAlign, NcAlpha, NcBoxMask, NcCell, NcPlane,
+    cstring, NcCell, NcPlane,
 };
 
 // Alpha -----------------------------------------------------------------------
 
-/// Gets the foreground [`NcAlpha`] from the [`NcPlane`], shifted to LSBs.
+/// Gets the foreground [`NcAlpha_u32`] from the [`NcPlane`], shifted to LSBs.
 ///
 /// *Method: NcPlane.[fg_alpha()][NcPlane#method.fg_alpha].*
 #[inline]
-pub fn ncplane_fg_alpha(plane: &NcPlane) -> NcAlpha {
+pub fn ncplane_fg_alpha(plane: &NcPlane) -> NcAlpha_u32 {
     c_api::ncchannels_fg_alpha(ncplane_channels(plane))
 }
 
-/// Gets the background [`NcAlpha`] from the [`NcPlane`], shifted to LSBs.
+/// Gets the background [`NcAlpha_u32`] from the [`NcPlane`], shifted to LSBs.
 ///
 /// *Method: NcPlane.[bg_alpha()][NcPlane#method.bg_alpha].*
 #[inline]
-pub fn ncplane_bg_alpha(plane: &NcPlane) -> NcAlpha {
+pub fn ncplane_bg_alpha(plane: &NcPlane) -> NcAlpha_u32 {
     c_api::ncchannels_bg_alpha(ncplane_channels(plane))
 }
 
 // NcChannel_u32 ---------------------------------------------------------------
 
-/// Gets the foreground [`NcChannel_u32`] from an [`NcPlane`].
+/// Gets the foreground alpha and coloring bits from an [`NcPlane`] as an [`NcChannel_u32`].
 ///
 /// *Method: NcPlane.[fchannel()][NcPlane#method.fchannel].*
 #[inline]
@@ -54,7 +54,7 @@ pub fn ncplane_fchannel(plane: &NcPlane) -> NcChannel_u32 {
     c_api::ncchannels_fchannel(ncplane_channels(plane))
 }
 
-/// Gets the background [`NcChannel_u32`] from an [`NcPlane`].
+/// Gets the background alpha and coloring bits from an [`NcPlane`] as an [`NcChannel_u32`].
 ///
 /// *Method: NcPlane.[bchannel()][NcPlane#method.bchannel].*
 #[inline]
@@ -62,22 +62,28 @@ pub fn ncplane_bchannel(plane: &NcPlane) -> NcChannel_u32 {
     c_api::ncchannels_bchannel(ncplane_channels(plane))
 }
 
-/// Sets the foreground [`NcChannel_u32`] on an [`NcPlane`],
+/// Sets the background alpha and coloring bits of an [`NcPlane`] from an [`NcChannel_u32`],
 /// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_fchannel()][NcPlane#method.set_fchannel].*
 #[inline]
-pub fn ncplane_set_fchannel(plane: &mut NcPlane, channel: NcChannel_u32) -> NcChannels_u64 {
-    unsafe { c_api::ffi::ncplane_set_fchannel(plane, channel) }
+pub fn ncplane_set_fchannel(
+    plane: &mut NcPlane,
+    channel: impl Into<NcChannel_u32>,
+) -> NcChannels_u64 {
+    unsafe { c_api::ffi::ncplane_set_fchannel(plane, channel.into()) }
 }
 
-/// Sets the background [`NcChannel_u32`] on an [`NcPlane`],
+/// Sets the background alpha and coloring bits of an [`NcPlane`] from an [`NcChannel_u32`],
 /// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_bchannel()][NcPlane#method.set_bchannel].*
 #[inline]
-pub fn ncplane_set_bchannel(plane: &mut NcPlane, channel: NcChannel_u32) -> NcChannels_u64 {
-    unsafe { c_api::ffi::ncplane_set_bchannel(plane, channel) }
+pub fn ncplane_set_bchannel(
+    plane: &mut NcPlane,
+    channel: impl Into<NcChannel_u32>,
+) -> NcChannels_u64 {
+    unsafe { c_api::ffi::ncplane_set_bchannel(plane, channel.into()) }
 }
 
 /// Gets the [`NcChannels_u64`] of an [`NcPlane`].
@@ -92,9 +98,9 @@ pub fn ncplane_channels(plane: &NcPlane) -> NcChannels_u64 {
 ///
 /// *Method: NcPlane.[set_channels()][NcPlane#method.set_channels].*
 #[inline]
-pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannels_u64) {
+pub fn ncplane_set_channels(plane: &mut NcPlane, channels: impl Into<NcChannels_u64>) {
     unsafe {
-        c_api::ffi::ncplane_set_channels(plane, channels);
+        c_api::ffi::ncplane_set_channels(plane, channels.into());
     }
 }
 
@@ -103,7 +109,7 @@ pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannels_u64) {
 /// Gets the foreground RGB components from an [`NcPlane`].
 /// and returns the background [`NcChannel_u32`].
 ///
-/// *Method: NcPlane.[fg_rgb8()][NcPlane#method.fg_rgb8].*
+/// *Method: NcPlane.[fg_rgb()][NcPlane#method.fg_rgb].*
 #[inline]
 pub fn ncplane_fg_rgb8(
     plane: &NcPlane,
@@ -117,7 +123,7 @@ pub fn ncplane_fg_rgb8(
 /// Gets the background RGB componentss from an [`NcPlane`],
 /// and returns the background [`NcChannel_u32`].
 ///
-/// *Method: NcPlane.[bg_rgb8()][NcPlane#method.bg_rgb8].*
+/// *Method: NcPlane.[bg_rgb()][NcPlane#method.bg_rgb].*
 #[inline]
 pub fn ncplane_bg_rgb8(
     plane: &NcPlane,
@@ -299,14 +305,11 @@ pub fn ncplane_putchar_stained(plane: &mut NcPlane, ch: char) -> NcResult_i32 {
 /// *Method: NcPlane.[putegc()][NcPlane#method.putegc].*
 #[inline]
 pub fn ncplane_putegc(plane: &mut NcPlane, egc: &str, sbytes: Option<&mut usize>) -> NcResult_i32 {
-    let sbytes_ptr;
-    if let Some(sb) = sbytes {
-        sbytes_ptr = sb as *mut _;
-    } else {
-        sbytes_ptr = null_mut();
-    }
+    let sbytes_ptr = if let Some(sb) = sbytes { sb as *mut _ } else { null_mut() };
+    let cs = cstring![egc];
+    let egc_ptr = cs.as_ptr() as *const i8; // CHECK why is this needed only here
 
-    unsafe { c_api::ffi::ncplane_putegc_yx(plane, -1, -1, cstring![egc], sbytes_ptr) }
+    unsafe { c_api::ffi::ncplane_putegc_yx(plane, -1, -1, egc_ptr, sbytes_ptr) }
 }
 
 /// Replaces the [`NcCell`] at the specified coordinates with the provided `egc`,
@@ -330,19 +333,15 @@ pub fn ncplane_putegc_yx(
     egc: &str,
     sbytes: Option<&mut usize>,
 ) -> NcResult_i32 {
-    let sbytes_ptr;
-    if let Some(sb) = sbytes {
-        sbytes_ptr = sb as *mut _;
-    } else {
-        sbytes_ptr = null_mut();
-    }
+    let sbytes_ptr = if let Some(sb) = sbytes { sb as *mut _ } else { null_mut() };
+    let cs = cstring![egc];
 
     unsafe {
         c_api::ffi::ncplane_putegc_yx(
             plane,
             y.unwrap_or(u32::MAX) as i32,
             x.unwrap_or(u32::MAX) as i32,
-            cstring![egc],
+            cs.as_ptr(),
             sbytes_ptr,
         )
     }
@@ -367,14 +366,10 @@ pub fn ncplane_putegc_stained(
     egc: &str,
     sbytes: Option<&mut usize>,
 ) -> NcResult_i32 {
-    let sbytes_ptr;
-    if let Some(sb) = sbytes {
-        sbytes_ptr = sb as *mut _;
-    } else {
-        sbytes_ptr = null_mut();
-    }
+    let sbytes_ptr = if let Some(sb) = sbytes { sb as *mut _ } else { null_mut() };
 
-    unsafe { c_api::ffi::ncplane_putegc_stained(plane, cstring![egc], sbytes_ptr) }
+    let cs = cstring![egc];
+    unsafe { c_api::ffi::ncplane_putegc_stained(plane, cs.as_ptr(), sbytes_ptr) }
 }
 
 /// Writes a string to the current location, using the current style.
@@ -413,20 +408,20 @@ pub fn ncplane_putstr_yx(
     x: Option<u32>,
     string: &str,
 ) -> NcResult_i32 {
-    let cstring = CString::new(string).unwrap();
-    let mut cstring_ptr = cstring.as_ptr();
+    let cs = cstring![string];
+    let mut cs_ptr = cs.as_ptr();
 
     let (mut y, mut x) = (y, x);
     let mut ret = 0;
 
-    while unsafe { cstring_ptr.read() != 0 } {
+    while unsafe { cs_ptr.read() != 0 } {
         let mut wcs = 0;
         let cols = unsafe {
             c_api::ffi::ncplane_putegc_yx(
                 plane,
                 y.unwrap_or(u32::MAX) as i32,
                 x.unwrap_or(u32::MAX) as i32,
-                cstring_ptr,
+                cs_ptr,
                 &mut wcs,
             )
         };
@@ -441,14 +436,14 @@ pub fn ncplane_putstr_yx(
         y = None;
         x = None;
 
-        cstring_ptr = unsafe { cstring_ptr.add(wcs) };
+        cs_ptr = unsafe { cs_ptr.add(wcs) };
         ret += cols;
     }
     ret
 }
 
 /// Writes a string to the provided location, using the current style
-/// and [`NcAlign`]ed on *x*.
+/// and [`NcAlign_u32`]ed on *x*.
 ///
 /// Advances the cursor by some positive number of columns (though not
 /// beyond the end of the plane); this number is returned on success.
@@ -464,17 +459,18 @@ pub fn ncplane_putstr_yx(
 pub fn ncplane_putstr_aligned(
     plane: &mut NcPlane,
     y: Option<u32>,
-    align: NcAlign,
+    align: impl Into<NcAlign_u32>,
     string: &str,
 ) -> NcResult_i32 {
     let (mut validbytes, mut validwidth) = (0, 0);
+    let cs = cstring![string];
 
     // we'll want to do the partial write if there's an error somewhere within
     unsafe {
-        c_api::ncstrwidth(cstring![string], &mut validbytes, &mut validwidth);
+        c_api::ncstrwidth(cs.as_ptr(), &mut validbytes, &mut validwidth);
     }
 
-    let xpos = ncplane_halign(plane, align, validwidth as u32);
+    let xpos = ncplane_halign(plane, align.into(), validwidth as u32);
     if xpos < 0 {
         NCRESULT_ERR
     } else {
@@ -727,11 +723,15 @@ pub fn ncplane_resize_simple(plane: &mut NcPlane, len_y: u32, len_x: u32) -> NcR
 /// aligned according to `align` within the `plane`.
 ///
 /// Returns `-`[`NCRESULT_MAX`][c_api::NCRESULT_MAX] if
-/// [NcAlign::Unaligned].
+/// [NCALIGN_UNALIGNED][c_api::NCALIGN_UNALIGNED].
 ///
 /// *Method: NcPlane.[halign()][NcPlane#method.halign].*
 #[inline]
-pub fn ncplane_halign(plane: &NcPlane, align: NcAlign, numcols: u32) -> NcResult_i32 {
+pub fn ncplane_halign(
+    plane: &NcPlane,
+    align: impl Into<NcAlign_u32> + Copy,
+    numcols: u32,
+) -> NcResult_i32 {
     c_api::notcurses_align(ncplane_dim_x(plane), align, numcols)
 }
 
@@ -739,11 +739,15 @@ pub fn ncplane_halign(plane: &NcPlane, align: NcAlign, numcols: u32) -> NcResult
 /// according to `align` within this NcPlane.
 ///
 /// Returns `-`[`NCRESULT_MAX`][c_api::NCRESULT_MAX] if
-/// [NcAlign::Unaligned].
+/// [NCALIGN_UNALIGNED][c_api::NCALIGN_UNALIGNED].
 ///
 /// *Method: NcPlane.[valign()][NcPlane#method.valign].*
 #[inline]
-pub fn ncplane_valign(plane: &NcPlane, align: NcAlign, numrows: u32) -> NcResult_i32 {
+pub fn ncplane_valign(
+    plane: &NcPlane,
+    align: impl Into<NcAlign_u32> + Copy,
+    numrows: u32,
+) -> NcResult_i32 {
     c_api::notcurses_align(ncplane_dim_y(plane), align, numrows)
 }
 
@@ -793,7 +797,7 @@ pub fn ncplane_perimeter(
     lr: &NcCell,
     hline: &NcCell,
     vline: &NcCell,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     unsafe {
         c_api::ncplane_cursor_move_yx(plane, 0, 0);
@@ -809,7 +813,7 @@ pub fn ncplane_perimeter(
             vline,
             dimy as u32,
             dimx as u32,
-            boxmask,
+            boxmask.into(),
         )
     }
 }
@@ -820,9 +824,9 @@ pub fn ncplane_perimeter(
 #[inline]
 pub fn ncplane_perimeter_double(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
-    boxmask: NcBoxMask,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
         return NCRESULT_ERR;
@@ -872,9 +876,9 @@ pub fn ncplane_perimeter_double(
 #[inline]
 pub fn ncplane_perimeter_rounded(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
-    boxmask: NcBoxMask,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
         return NCRESULT_ERR;
@@ -926,11 +930,11 @@ pub fn ncplane_perimeter_rounded(
 #[inline]
 pub fn ncplane_ascii_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     end_y: u32,
     end_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     #[allow(unused_assignments)]
     let mut ret = NCRESULT_OK;
@@ -990,7 +994,7 @@ pub fn ncplane_box_sized(
     vline: &NcCell,
     len_y: u32,
     len_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
@@ -1017,11 +1021,11 @@ pub fn ncplane_box_sized(
 #[inline]
 pub fn ncplane_double_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     end_y: u32,
     end_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     #[allow(unused_assignments)]
     let mut ret = NCRESULT_OK;
@@ -1068,11 +1072,11 @@ pub fn ncplane_double_box(
 #[inline]
 pub fn ncplane_double_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     len_y: u32,
     len_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
@@ -1095,11 +1099,11 @@ pub fn ncplane_double_box_sized(
 #[inline]
 pub fn ncplane_rounded_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     end_y: u32,
     end_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     #[allow(unused_assignments)]
     let mut ret = NCRESULT_OK;
@@ -1145,11 +1149,11 @@ pub fn ncplane_rounded_box(
 #[inline]
 pub fn ncplane_rounded_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyle_u16,
-    channels: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    channels: impl Into<NcChannels_u64>,
     len_y: u32,
     len_x: u32,
-    boxmask: NcBoxMask,
+    boxmask: impl Into<NcBoxMask_u32>,
 ) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
@@ -1204,16 +1208,18 @@ pub fn ncplane_gradient(
     len_y: Option<u32>,
     len_x: Option<u32>,
     egc: &str,
-    stylemask: NcStyle_u16,
-    ul: NcChannels_u64,
-    ur: NcChannels_u64,
-    ll: NcChannels_u64,
-    lr: NcChannels_u64,
+    stylemask: impl Into<NcStyle_u16>,
+    ul: impl Into<NcChannels_u64>,
+    ur: impl Into<NcChannels_u64>,
+    ll: impl Into<NcChannels_u64>,
+    lr: impl Into<NcChannels_u64>,
 ) -> NcResult_i32 {
+    let cs = cstring![egc];
+
     #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
-    let egc_ptr = cstring![egc] as *const i8;
+    let egc_ptr = cs.as_ptr() as *const i8;
     #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
-    let egc_ptr = cstring![egc];
+    let egc_ptr = cs.as_ptr();
 
     unsafe {
         c_api::ffi::ncplane_gradient(
@@ -1223,11 +1229,11 @@ pub fn ncplane_gradient(
             len_y.unwrap_or(0),
             len_x.unwrap_or(0),
             egc_ptr,
-            stylemask,
-            ul,
-            ur,
-            ll,
-            lr,
+            stylemask.into(),
+            ul.into(),
+            ur.into(),
+            ll.into(),
+            lr.into(),
         )
     }
 }
