@@ -41,8 +41,9 @@ impl NcVisual {
     ///
     /// *C style function: [ncvisual_from_file()][c_api::ncvisual_from_file].*
     pub fn from_file<'a>(file: &str) -> NcResult<&'a mut NcVisual> {
+        let cs = cstring![file];
         error_ref_mut![
-            unsafe { c_api::ncvisual_from_file(cstring![file]) },
+            unsafe { c_api::ncvisual_from_file(cs.as_ptr()) },
             &format!("NcVisual::from_file({})", file)
         ]
     }
@@ -67,7 +68,7 @@ impl NcVisual {
     /// *C style function: [ncvisual_from_plane()][c_api::ncvisual_from_plane].*
     pub fn from_plane<'a>(
         plane: &NcPlane,
-        blitter: NcBlitter,
+        blitter: impl Into<NcBlitter> + Copy,
         beg_y: Option<u32>,
         beg_x: Option<u32>,
         len_y: Option<u32>,
@@ -77,7 +78,7 @@ impl NcVisual {
             unsafe {
                 c_api::ncvisual_from_plane(
                     plane,
-                    blitter.into(),
+                    blitter.into().into(),
                     beg_y.unwrap_or(u32::MAX) as i32,
                     beg_x.unwrap_or(u32::MAX) as i32,
                     len_y.unwrap_or(0),
@@ -86,7 +87,11 @@ impl NcVisual {
             },
             &format!(
                 "NcVisual::from_file(plane, {}, {:?}, {:?}, {:?}, {:?})",
-                blitter, beg_y, beg_x, len_y, len_x
+                blitter.into(),
+                beg_y,
+                beg_x,
+                len_y,
+                len_x
             )
         ]
     }
@@ -95,8 +100,9 @@ impl NcVisual {
     ///
     /// *C style function: [ncvisual_from_sixel()][c_api::ncvisual_from_sixel].*
     pub fn from_sixel<'a>(sequence: &str, len_y: u32, len_x: u32) -> NcResult<&'a mut NcVisual> {
+        let cs = cstring![sequence];
         error_ref_mut![
-            unsafe { c_api::ncvisual_from_file(cstring![sequence]) },
+            unsafe { c_api::ncvisual_from_file(cs.as_ptr()) },
             &format!("NcVisual::from_sixel({}, {}, {})", sequence, len_y, len_x)
         ]
     }
@@ -310,19 +316,9 @@ impl NcVisual {
     ) -> NcResult<NcVisualGeometry> {
         let mut vg = c_api::NcVGeom::new();
 
-        let nc_ptr: *const Nc;
-        if let Some(nc) = nc {
-            nc_ptr = nc;
-        } else {
-            nc_ptr = null();
-        }
-        let vo_ptr: *const NcVisualOptions;
-        if let Some(o) = vopts {
-            vo_ptr = o;
-        } else {
-            let vo = NcVisualOptions::default();
-            vo_ptr = &vo;
-        }
+        let nc_ptr: *const Nc = if let Some(nc) = nc { nc } else { null() };
+        let vo_ptr: *const NcVisualOptions =
+            if let Some(o) = vopts { o } else { &NcVisualOptions::default() };
 
         let res = unsafe { crate::c_api::ncvisual_geom(nc_ptr, self, vo_ptr, &mut vg) };
         if res <= c_api::NCRESULT_ERR {
@@ -423,17 +419,14 @@ impl NcVisual {
     /// [`Half`]: NcBlitter::Half
     /// [`Quadrant`]: NcBlitter::Quadrant
     /// [`Sextant`]: NcBlitter::Sextant
-    pub fn media_defblitter(nc: &Nc, scale: NcScale) -> NcBlitter {
-        unsafe { c_api::ncvisual_media_defblitter(nc, scale.into()).into() }
+    pub fn media_defblitter(nc: &Nc, scale: impl Into<NcScale>) -> NcBlitter {
+        unsafe { c_api::ncvisual_media_defblitter(nc, scale.into().into()).into() }
     }
 
     /// Polyfills at the specified location using `rgba`.
     ///
     /// *C style function: [ncvisual_polyfill_yx()][c_api::ncvisual_polyfill_yx].*
-    pub fn polyfill_yx<RGBA>(&mut self, y: u32, x: u32, rgba: RGBA) -> NcResult<()>
-    where
-        RGBA: Into<NcRgba>,
-    {
+    pub fn polyfill_yx(&mut self, y: u32, x: u32, rgba: impl Into<NcRgba>) -> NcResult<()> {
         error![
             unsafe { c_api::ncvisual_polyfill_yx(self, y, x, rgba.into().into()) },
             &format!["NcVisual.polyfill_yx({}, {}, rgba)", y, x]
@@ -525,10 +518,10 @@ impl NcVisual {
     /// Sets the specified pixel.
     ///
     /// *C style function: [ncvisual_set_yx()][c_api::ncvisual_set_yx].*
-    pub fn set_yx(&mut self, y: u32, x: u32, pixel: NcPixel) -> NcResult<()> {
+    pub fn set_yx(&mut self, y: u32, x: u32, pixel: impl Into<NcPixel> + Copy) -> NcResult<()> {
         error![
-            unsafe { c_api::ncvisual_set_yx(self, y, x, pixel.into()) },
-            &format!["NcVisual.set_yx({}, {}, {:?})", y, x, pixel]
+            unsafe { c_api::ncvisual_set_yx(self, y, x, pixel.into().into()) },
+            &format!["NcVisual.set_yx({}, {}, {:?})", y, x, pixel.into()]
         ]
     }
 
@@ -626,8 +619,9 @@ impl NcVisual {
     ///
     /// *C style function: [ncdirectf_from_file()][c_api::ncdirectf_from_file].*
     pub fn ncdirectf_from_file<'a>(ncd: &mut NcDirect, file: &str) -> NcResult<&'a mut NcVisual> {
+        let cs = cstring![file];
         error_ref_mut![
-            unsafe { c_api::ncdirectf_from_file(ncd, cstring![file]) },
+            unsafe { c_api::ncdirectf_from_file(ncd, cs.as_ptr()) },
             &format!("NcVisual::ncdirectf_from_file(ncd, {})", file)
         ]
     }
