@@ -38,12 +38,14 @@
 //   nctabbed_tabcount
 //   nctablet_ncplane
 
+use crate::c_api::ffi;
+
 // mod methods;
 
 /// A tab for [`NcTabbed`].
 ///
 /// `type in C: nctab (struct)`
-pub type NcTab = crate::bindings::ffi::nctab;
+pub type NcTab = ffi::nctab;
 
 /// Tabbed widgets.
 ///
@@ -51,19 +53,21 @@ pub type NcTab = crate::bindings::ffi::nctab;
 /// and only one tab is visible at a time.
 ///
 /// `type in C: nctabbed (struct)`
-pub type NcTabbed = crate::bindings::ffi::nctabbed;
+pub type NcTabbed = ffi::nctabbed;
 
 /// Options for [`NcTabbed`].
 ///
 /// `type in C: nctabbed_options (struct)`
-pub type NcTabbedOptions = crate::bindings::ffi::nctabbed_options;
+pub type NcTabbedOptions = ffi::nctabbed_options;
 
 impl NcTabbedOptions {
     /// To display the tab list at the bottom instead of at the top of the plane.
-    pub const BOTTOM: u32 = constants::NCTABBED_OPTION_BOTTOM;
+    pub const BOTTOM: u32 = c_api::NCTABBED_OPTION_BOTTOM;
 }
 
-pub(crate) mod constants {
+pub(crate) mod c_api {
+    use super::ffi;
+
     /// To display the tab list at the bottom instead of at the top of the plane.
-    pub const NCTABBED_OPTION_BOTTOM: u32 = crate::bindings::ffi::NCTABBED_OPTION_BOTTOM;
+    pub const NCTABBED_OPTION_BOTTOM: u32 = ffi::NCTABBED_OPTION_BOTTOM;
 }
